// Copyright 2015, VIXL authors
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
//   * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//   * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//   * Neither the name of ARM Limited nor the names of its contributors may be
//     used to endorse or promote products derived from this software without
//     specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.


// ---------------------------------------------------------------------
// This file is auto generated using tools/generate_simulator_traces.py.
//
// PLEASE DO NOT EDIT.
// ---------------------------------------------------------------------

#ifndef VIXL_ASSEMBLER_COND_RD_MEMOP_RS_LDR_A32_H_
#define VIXL_ASSEMBLER_COND_RD_MEMOP_RS_LDR_A32_H_

const byte kInstruction_ldr_pl_r8_r11_plus_r6_Offset[] = {
  0x06, 0x80, 0x9b, 0x57 // ldr pl r8 r11 plus r6 Offset
};
const byte kInstruction_ldr_le_r4_r8_plus_r5_Offset[] = {
  0x05, 0x40, 0x98, 0xd7 // ldr le r4 r8 plus r5 Offset
};
const byte kInstruction_ldr_vs_r2_r6_plus_r14_Offset[] = {
  0x0e, 0x20, 0x96, 0x67 // ldr vs r2 r6 plus r14 Offset
};
const byte kInstruction_ldr_ls_r1_r7_plus_r8_Offset[] = {
  0x08, 0x10, 0x97, 0x97 // ldr ls r1 r7 plus r8 Offset
};
const byte kInstruction_ldr_ge_r14_r6_plus_r14_Offset[] = {
  0x0e, 0xe0, 0x96, 0xa7 // ldr ge r14 r6 plus r14 Offset
};
const byte kInstruction_ldr_cs_r7_r0_plus_r7_Offset[] = {
  0x07, 0x70, 0x90, 0x27 // ldr cs r7 r0 plus r7 Offset
};
const byte kInstruction_ldr_ge_r11_r0_plus_r9_Offset[] = {
  0x09, 0xb0, 0x90, 0xa7 // ldr ge r11 r0 plus r9 Offset
};
const byte kInstruction_ldr_eq_r7_r10_plus_r4_Offset[] = {
  0x04, 0x70, 0x9a, 0x07 // ldr eq r7 r10 plus r4 Offset
};
const byte kInstruction_ldr_al_r9_r2_plus_r3_Offset[] = {
  0x03, 0x90, 0x92, 0xe7 // ldr al r9 r2 plus r3 Offset
};
const byte kInstruction_ldr_cc_r11_r10_plus_r6_Offset[] = {
  0x06, 0xb0, 0x9a, 0x37 // ldr cc r11 r10 plus r6 Offset
};
const byte kInstruction_ldr_lt_r9_r6_plus_r1_Offset[] = {
  0x01, 0x90, 0x96, 0xb7 // ldr lt r9 r6 plus r1 Offset
};
const byte kInstruction_ldr_ge_r4_r0_plus_r4_Offset[] = {
  0x04, 0x40, 0x90, 0xa7 // ldr ge r4 r0 plus r4 Offset
};
const byte kInstruction_ldr_al_r9_r13_plus_r14_Offset[] = {
  0x0e, 0x90, 0x9d, 0xe7 // ldr al r9 r13 plus r14 Offset
};
const byte kInstruction_ldr_cc_r9_r0_plus_r7_Offset[] = {
  0x07, 0x90, 0x90, 0x37 // ldr cc r9 r0 plus r7 Offset
};
const byte kInstruction_ldr_cs_r11_r7_plus_r8_Offset[] = {
  0x08, 0xb0, 0x97, 0x27 // ldr cs r11 r7 plus r8 Offset
};
const byte kInstruction_ldr_eq_r8_r0_plus_r8_Offset[] = {
  0x08, 0x80, 0x90, 0x07 // ldr eq r8 r0 plus r8 Offset
};
const byte kInstruction_ldr_hi_r9_r10_plus_r8_Offset[] = {
  0x08, 0x90, 0x9a, 0x87 // ldr hi r9 r10 plus r8 Offset
};
const byte kInstruction_ldr_le_r8_r0_plus_r0_Offset[] = {
  0x00, 0x80, 0x90, 0xd7 // ldr le r8 r0 plus r0 Offset
};
const byte kInstruction_ldr_cs_r4_r5_plus_r2_Offset[] = {
  0x02, 0x40, 0x95, 0x27 // ldr cs r4 r5 plus r2 Offset
};
const byte kInstruction_ldr_eq_r14_r11_plus_r8_Offset[] = {
  0x08, 0xe0, 0x9b, 0x07 // ldr eq r14 r11 plus r8 Offset
};
const byte kInstruction_ldr_cs_r7_r6_plus_r14_Offset[] = {
  0x0e, 0x70, 0x96, 0x27 // ldr cs r7 r6 plus r14 Offset
};
const byte kInstruction_ldr_ne_r0_r9_plus_r7_Offset[] = {
  0x07, 0x00, 0x99, 0x17 // ldr ne r0 r9 plus r7 Offset
};
const byte kInstruction_ldr_le_r7_r3_plus_r11_Offset[] = {
  0x0b, 0x70, 0x93, 0xd7 // ldr le r7 r3 plus r11 Offset
};
const byte kInstruction_ldr_gt_r7_r9_plus_r9_Offset[] = {
  0x09, 0x70, 0x99, 0xc7 // ldr gt r7 r9 plus r9 Offset
};
const byte kInstruction_ldr_le_r9_r12_plus_r9_Offset[] = {
  0x09, 0x90, 0x9c, 0xd7 // ldr le r9 r12 plus r9 Offset
};
const byte kInstruction_ldr_pl_r2_r11_plus_r14_Offset[] = {
  0x0e, 0x20, 0x9b, 0x57 // ldr pl r2 r11 plus r14 Offset
};
const byte kInstruction_ldr_cs_r1_r7_plus_r2_Offset[] = {
  0x02, 0x10, 0x97, 0x27 // ldr cs r1 r7 plus r2 Offset
};
const byte kInstruction_ldr_al_r5_r1_plus_r12_Offset[] = {
  0x0c, 0x50, 0x91, 0xe7 // ldr al r5 r1 plus r12 Offset
};
const byte kInstruction_ldr_eq_r10_r13_plus_r12_Offset[] = {
  0x0c, 0xa0, 0x9d, 0x07 // ldr eq r10 r13 plus r12 Offset
};
const byte kInstruction_ldr_eq_r10_r11_plus_r3_Offset[] = {
  0x03, 0xa0, 0x9b, 0x07 // ldr eq r10 r11 plus r3 Offset
};
const byte kInstruction_ldr_al_r9_r12_plus_r0_Offset[] = {
  0x00, 0x90, 0x9c, 0xe7 // ldr al r9 r12 plus r0 Offset
};
const byte kInstruction_ldr_ls_r3_r14_plus_r1_Offset[] = {
  0x01, 0x30, 0x9e, 0x97 // ldr ls r3 r14 plus r1 Offset
};
const byte kInstruction_ldr_le_r13_r4_plus_r9_Offset[] = {
  0x09, 0xd0, 0x94, 0xd7 // ldr le r13 r4 plus r9 Offset
};
const byte kInstruction_ldr_ls_r3_r14_plus_r3_Offset[] = {
  0x03, 0x30, 0x9e, 0x97 // ldr ls r3 r14 plus r3 Offset
};
const byte kInstruction_ldr_cc_r7_r4_plus_r4_Offset[] = {
  0x04, 0x70, 0x94, 0x37 // ldr cc r7 r4 plus r4 Offset
};
const byte kInstruction_ldr_ls_r5_r9_plus_r5_Offset[] = {
  0x05, 0x50, 0x99, 0x97 // ldr ls r5 r9 plus r5 Offset
};
const byte kInstruction_ldr_ge_r6_r4_plus_r13_Offset[] = {
  0x0d, 0x60, 0x94, 0xa7 // ldr ge r6 r4 plus r13 Offset
};
const byte kInstruction_ldr_al_r1_r11_plus_r12_Offset[] = {
  0x0c, 0x10, 0x9b, 0xe7 // ldr al r1 r11 plus r12 Offset
};
const byte kInstruction_ldr_le_r6_r11_plus_r3_Offset[] = {
  0x03, 0x60, 0x9b, 0xd7 // ldr le r6 r11 plus r3 Offset
};
const byte kInstruction_ldr_al_r6_r6_plus_r13_Offset[] = {
  0x0d, 0x60, 0x96, 0xe7 // ldr al r6 r6 plus r13 Offset
};
const byte kInstruction_ldr_gt_r14_r11_plus_r2_Offset[] = {
  0x02, 0xe0, 0x9b, 0xc7 // ldr gt r14 r11 plus r2 Offset
};
const byte kInstruction_ldr_vs_r5_r8_plus_r12_Offset[] = {
  0x0c, 0x50, 0x98, 0x67 // ldr vs r5 r8 plus r12 Offset
};
const byte kInstruction_ldr_ls_r8_r12_plus_r6_Offset[] = {
  0x06, 0x80, 0x9c, 0x97 // ldr ls r8 r12 plus r6 Offset
};
const byte kInstruction_ldr_vs_r6_r12_plus_r14_Offset[] = {
  0x0e, 0x60, 0x9c, 0x67 // ldr vs r6 r12 plus r14 Offset
};
const byte kInstruction_ldr_pl_r7_r2_plus_r7_Offset[] = {
  0x07, 0x70, 0x92, 0x57 // ldr pl r7 r2 plus r7 Offset
};
const byte kInstruction_ldr_gt_r5_r4_plus_r13_Offset[] = {
  0x0d, 0x50, 0x94, 0xc7 // ldr gt r5 r4 plus r13 Offset
};
const byte kInstruction_ldr_hi_r2_r7_plus_r12_Offset[] = {
  0x0c, 0x20, 0x97, 0x87 // ldr hi r2 r7 plus r12 Offset
};
const byte kInstruction_ldr_ne_r2_r3_plus_r10_Offset[] = {
  0x0a, 0x20, 0x93, 0x17 // ldr ne r2 r3 plus r10 Offset
};
const byte kInstruction_ldr_lt_r13_r2_plus_r6_Offset[] = {
  0x06, 0xd0, 0x92, 0xb7 // ldr lt r13 r2 plus r6 Offset
};
const byte kInstruction_ldr_hi_r14_r10_plus_r11_Offset[] = {
  0x0b, 0xe0, 0x9a, 0x87 // ldr hi r14 r10 plus r11 Offset
};
const byte kInstruction_ldr_hi_r7_r10_plus_r12_Offset[] = {
  0x0c, 0x70, 0x9a, 0x87 // ldr hi r7 r10 plus r12 Offset
};
const byte kInstruction_ldr_cs_r3_r12_plus_r2_Offset[] = {
  0x02, 0x30, 0x9c, 0x27 // ldr cs r3 r12 plus r2 Offset
};
const byte kInstruction_ldr_ls_r11_r5_plus_r1_Offset[] = {
  0x01, 0xb0, 0x95, 0x97 // ldr ls r11 r5 plus r1 Offset
};
const byte kInstruction_ldr_hi_r5_r2_plus_r11_Offset[] = {
  0x0b, 0x50, 0x92, 0x87 // ldr hi r5 r2 plus r11 Offset
};
const byte kInstruction_ldr_cc_r11_r8_plus_r6_Offset[] = {
  0x06, 0xb0, 0x98, 0x37 // ldr cc r11 r8 plus r6 Offset
};
const byte kInstruction_ldr_lt_r11_r3_plus_r9_Offset[] = {
  0x09, 0xb0, 0x93, 0xb7 // ldr lt r11 r3 plus r9 Offset
};
const byte kInstruction_ldr_ne_r11_r9_plus_r8_Offset[] = {
  0x08, 0xb0, 0x99, 0x17 // ldr ne r11 r9 plus r8 Offset
};
const byte kInstruction_ldr_lt_r7_r0_plus_r14_Offset[] = {
  0x0e, 0x70, 0x90, 0xb7 // ldr lt r7 r0 plus r14 Offset
};
const byte kInstruction_ldr_ge_r12_r3_plus_r1_Offset[] = {
  0x01, 0xc0, 0x93, 0xa7 // ldr ge r12 r3 plus r1 Offset
};
const byte kInstruction_ldr_le_r0_r8_plus_r13_Offset[] = {
  0x0d, 0x00, 0x98, 0xd7 // ldr le r0 r8 plus r13 Offset
};
const byte kInstruction_ldr_vc_r5_r13_plus_r7_Offset[] = {
  0x07, 0x50, 0x9d, 0x77 // ldr vc r5 r13 plus r7 Offset
};
const byte kInstruction_ldr_ge_r7_r5_plus_r11_Offset[] = {
  0x0b, 0x70, 0x95, 0xa7 // ldr ge r7 r5 plus r11 Offset
};
const byte kInstruction_ldr_ge_r10_r9_plus_r3_Offset[] = {
  0x03, 0xa0, 0x99, 0xa7 // ldr ge r10 r9 plus r3 Offset
};
const byte kInstruction_ldr_vs_r9_r5_plus_r2_Offset[] = {
  0x02, 0x90, 0x95, 0x67 // ldr vs r9 r5 plus r2 Offset
};
const byte kInstruction_ldr_hi_r2_r10_plus_r4_Offset[] = {
  0x04, 0x20, 0x9a, 0x87 // ldr hi r2 r10 plus r4 Offset
};
const byte kInstruction_ldr_ge_r1_r11_plus_r1_Offset[] = {
  0x01, 0x10, 0x9b, 0xa7 // ldr ge r1 r11 plus r1 Offset
};
const byte kInstruction_ldr_ls_r9_r14_plus_r12_Offset[] = {
  0x0c, 0x90, 0x9e, 0x97 // ldr ls r9 r14 plus r12 Offset
};
const byte kInstruction_ldr_mi_r1_r9_plus_r4_Offset[] = {
  0x04, 0x10, 0x99, 0x47 // ldr mi r1 r9 plus r4 Offset
};
const byte kInstruction_ldr_mi_r7_r10_plus_r4_Offset[] = {
  0x04, 0x70, 0x9a, 0x47 // ldr mi r7 r10 plus r4 Offset
};
const byte kInstruction_ldr_gt_r6_r2_plus_r5_Offset[] = {
  0x05, 0x60, 0x92, 0xc7 // ldr gt r6 r2 plus r5 Offset
};
const byte kInstruction_ldr_eq_r10_r8_plus_r11_Offset[] = {
  0x0b, 0xa0, 0x98, 0x07 // ldr eq r10 r8 plus r11 Offset
};
const byte kInstruction_ldr_le_r10_r1_plus_r7_Offset[] = {
  0x07, 0xa0, 0x91, 0xd7 // ldr le r10 r1 plus r7 Offset
};
const byte kInstruction_ldr_pl_r8_r14_plus_r8_Offset[] = {
  0x08, 0x80, 0x9e, 0x57 // ldr pl r8 r14 plus r8 Offset
};
const byte kInstruction_ldr_gt_r5_r1_plus_r3_Offset[] = {
  0x03, 0x50, 0x91, 0xc7 // ldr gt r5 r1 plus r3 Offset
};
const byte kInstruction_ldr_cs_r10_r4_plus_r13_Offset[] = {
  0x0d, 0xa0, 0x94, 0x27 // ldr cs r10 r4 plus r13 Offset
};
const byte kInstruction_ldr_mi_r10_r5_plus_r2_Offset[] = {
  0x02, 0xa0, 0x95, 0x47 // ldr mi r10 r5 plus r2 Offset
};
const byte kInstruction_ldr_cc_r6_r0_plus_r11_Offset[] = {
  0x0b, 0x60, 0x90, 0x37 // ldr cc r6 r0 plus r11 Offset
};
const byte kInstruction_ldr_eq_r3_r9_plus_r2_Offset[] = {
  0x02, 0x30, 0x99, 0x07 // ldr eq r3 r9 plus r2 Offset
};
const byte kInstruction_ldr_al_r1_r0_plus_r3_Offset[] = {
  0x03, 0x10, 0x90, 0xe7 // ldr al r1 r0 plus r3 Offset
};
const byte kInstruction_ldr_mi_r1_r0_plus_r13_Offset[] = {
  0x0d, 0x10, 0x90, 0x47 // ldr mi r1 r0 plus r13 Offset
};
const byte kInstruction_ldr_cc_r4_r4_plus_r5_Offset[] = {
  0x05, 0x40, 0x94, 0x37 // ldr cc r4 r4 plus r5 Offset
};
const byte kInstruction_ldr_al_r2_r6_plus_r11_Offset[] = {
  0x0b, 0x20, 0x96, 0xe7 // ldr al r2 r6 plus r11 Offset
};
const byte kInstruction_ldr_ls_r1_r5_plus_r4_Offset[] = {
  0x04, 0x10, 0x95, 0x97 // ldr ls r1 r5 plus r4 Offset
};
const byte kInstruction_ldr_eq_r0_r3_plus_r4_Offset[] = {
  0x04, 0x00, 0x93, 0x07 // ldr eq r0 r3 plus r4 Offset
};
const byte kInstruction_ldr_lt_r7_r11_plus_r10_Offset[] = {
  0x0a, 0x70, 0x9b, 0xb7 // ldr lt r7 r11 plus r10 Offset
};
const byte kInstruction_ldr_vc_r3_r0_plus_r13_Offset[] = {
  0x0d, 0x30, 0x90, 0x77 // ldr vc r3 r0 plus r13 Offset
};
const byte kInstruction_ldr_ls_r3_r3_plus_r7_Offset[] = {
  0x07, 0x30, 0x93, 0x97 // ldr ls r3 r3 plus r7 Offset
};
const byte kInstruction_ldr_al_r5_r14_plus_r3_Offset[] = {
  0x03, 0x50, 0x9e, 0xe7 // ldr al r5 r14 plus r3 Offset
};
const byte kInstruction_ldr_ne_r2_r13_plus_r9_Offset[] = {
  0x09, 0x20, 0x9d, 0x17 // ldr ne r2 r13 plus r9 Offset
};
const byte kInstruction_ldr_lt_r6_r2_plus_r11_Offset[] = {
  0x0b, 0x60, 0x92, 0xb7 // ldr lt r6 r2 plus r11 Offset
};
const byte kInstruction_ldr_vc_r9_r2_plus_r13_Offset[] = {
  0x0d, 0x90, 0x92, 0x77 // ldr vc r9 r2 plus r13 Offset
};
const byte kInstruction_ldr_ne_r5_r9_plus_r6_Offset[] = {
  0x06, 0x50, 0x99, 0x17 // ldr ne r5 r9 plus r6 Offset
};
const byte kInstruction_ldr_vc_r4_r9_plus_r8_Offset[] = {
  0x08, 0x40, 0x99, 0x77 // ldr vc r4 r9 plus r8 Offset
};
const byte kInstruction_ldr_cc_r6_r9_plus_r2_Offset[] = {
  0x02, 0x60, 0x99, 0x37 // ldr cc r6 r9 plus r2 Offset
};
const byte kInstruction_ldr_vs_r8_r7_plus_r13_Offset[] = {
  0x0d, 0x80, 0x97, 0x67 // ldr vs r8 r7 plus r13 Offset
};
const byte kInstruction_ldr_pl_r14_r14_plus_r7_Offset[] = {
  0x07, 0xe0, 0x9e, 0x57 // ldr pl r14 r14 plus r7 Offset
};
const byte kInstruction_ldr_eq_r8_r2_plus_r6_Offset[] = {
  0x06, 0x80, 0x92, 0x07 // ldr eq r8 r2 plus r6 Offset
};
const byte kInstruction_ldr_al_r13_r13_plus_r13_Offset[] = {
  0x0d, 0xd0, 0x9d, 0xe7 // ldr al r13 r13 plus r13 Offset
};
const byte kInstruction_ldr_gt_r12_r14_plus_r5_Offset[] = {
  0x05, 0xc0, 0x9e, 0xc7 // ldr gt r12 r14 plus r5 Offset
};
const byte kInstruction_ldr_lt_r14_r7_plus_r1_Offset[] = {
  0x01, 0xe0, 0x97, 0xb7 // ldr lt r14 r7 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r2_Offset[] = {
  0x02, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r8_Offset[] = {
  0x08, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r14_Offset[] = {
  0x0e, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r14 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r6_Offset[] = {
  0x06, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r8_Offset[] = {
  0x08, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r10_Offset[] = {
  0x0a, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r1_Offset[] = {
  0x01, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r2_minus_r7_Offset[] = {
  0x07, 0x00, 0x12, 0xe7 // ldr al r0 r2 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r7_Offset[] = {
  0x07, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r3_Offset[] = {
  0x03, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r3 Offset
};
const byte kInstruction_ldr_al_r0_r4_minus_r11_Offset[] = {
  0x0b, 0x00, 0x14, 0xe7 // ldr al r0 r4 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r9_Offset[] = {
  0x09, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r14_Offset[] = {
  0x0e, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r4_minus_r1_Offset[] = {
  0x01, 0x00, 0x14, 0xe7 // ldr al r0 r4 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r4_Offset[] = {
  0x04, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r5_Offset[] = {
  0x05, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r9_Offset[] = {
  0x09, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r5_Offset[] = {
  0x05, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r11_Offset[] = {
  0x0b, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r11 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r0_Offset[] = {
  0x00, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r2_Offset[] = {
  0x02, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r1_plus_r14_Offset[] = {
  0x0e, 0x00, 0x91, 0xe7 // ldr al r0 r1 plus r14 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r12_Offset[] = {
  0x0c, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r12 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r11_Offset[] = {
  0x0b, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r0_Offset[] = {
  0x00, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r0 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r13_Offset[] = {
  0x0d, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r4_Offset[] = {
  0x04, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r4_Offset[] = {
  0x04, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r4_minus_r14_Offset[] = {
  0x0e, 0x00, 0x14, 0xe7 // ldr al r0 r4 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r9_Offset[] = {
  0x09, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r3_plus_r10_Offset[] = {
  0x0a, 0x00, 0x93, 0xe7 // ldr al r0 r3 plus r10 Offset
};
const byte kInstruction_ldr_al_r0_r4_minus_r3_Offset[] = {
  0x03, 0x00, 0x14, 0xe7 // ldr al r0 r4 minus r3 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r9_Offset[] = {
  0x09, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r9 Offset
};
const byte kInstruction_ldr_al_r0_r3_plus_r1_Offset[] = {
  0x01, 0x00, 0x93, 0xe7 // ldr al r0 r3 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r7_Offset[] = {
  0x07, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r6_plus_r9_Offset[] = {
  0x09, 0x00, 0x96, 0xe7 // ldr al r0 r6 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r7_Offset[] = {
  0x07, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r0_Offset[] = {
  0x00, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r3_Offset[] = {
  0x03, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r4_Offset[] = {
  0x04, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r7_Offset[] = {
  0x07, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r0_Offset[] = {
  0x00, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r11_Offset[] = {
  0x0b, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r0_plus_r4_Offset[] = {
  0x04, 0x00, 0x90, 0xe7 // ldr al r0 r0 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r1_plus_r10_Offset[] = {
  0x0a, 0x00, 0x91, 0xe7 // ldr al r0 r1 plus r10 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r6_Offset[] = {
  0x06, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r2_minus_r8_Offset[] = {
  0x08, 0x00, 0x12, 0xe7 // ldr al r0 r2 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r4_minus_r4_Offset[] = {
  0x04, 0x00, 0x14, 0xe7 // ldr al r0 r4 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r1_Offset[] = {
  0x01, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r13_Offset[] = {
  0x0d, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r6_plus_r12_Offset[] = {
  0x0c, 0x00, 0x96, 0xe7 // ldr al r0 r6 plus r12 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r3_Offset[] = {
  0x03, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r14_plus_r11_Offset[] = {
  0x0b, 0x00, 0x9e, 0xe7 // ldr al r0 r14 plus r11 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r1_Offset[] = {
  0x01, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r11_Offset[] = {
  0x0b, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r11 Offset
};
const byte kInstruction_ldr_al_r0_r8_plus_r13_Offset[] = {
  0x0d, 0x00, 0x98, 0xe7 // ldr al r0 r8 plus r13 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r4_Offset[] = {
  0x04, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r10_Offset[] = {
  0x0a, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r10 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r4_Offset[] = {
  0x04, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r7_Offset[] = {
  0x07, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r3_minus_r12_Offset[] = {
  0x0c, 0x00, 0x13, 0xe7 // ldr al r0 r3 minus r12 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r10_Offset[] = {
  0x0a, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r4_Offset[] = {
  0x04, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r1_plus_r3_Offset[] = {
  0x03, 0x00, 0x91, 0xe7 // ldr al r0 r1 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r10_Offset[] = {
  0x0a, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r0_Offset[] = {
  0x00, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r13_Offset[] = {
  0x0d, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r7_Offset[] = {
  0x07, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r8_Offset[] = {
  0x08, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r8 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r5_Offset[] = {
  0x05, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r5 Offset
};
const byte kInstruction_ldr_al_r0_r0_plus_r6_Offset[] = {
  0x06, 0x00, 0x90, 0xe7 // ldr al r0 r0 plus r6 Offset
};
const byte kInstruction_ldr_al_r0_r11_minus_r0_Offset[] = {
  0x00, 0x00, 0x1b, 0xe7 // ldr al r0 r11 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r13_Offset[] = {
  0x0d, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r13 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r2_Offset[] = {
  0x02, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r2_minus_r6_Offset[] = {
  0x06, 0x00, 0x12, 0xe7 // ldr al r0 r2 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r10_Offset[] = {
  0x0a, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r10 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r0_Offset[] = {
  0x00, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r13_Offset[] = {
  0x0d, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r0_Offset[] = {
  0x00, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r5_plus_r2_Offset[] = {
  0x02, 0x00, 0x95, 0xe7 // ldr al r0 r5 plus r2 Offset
};
const byte kInstruction_ldr_al_r0_r11_minus_r10_Offset[] = {
  0x0a, 0x00, 0x1b, 0xe7 // ldr al r0 r11 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r8_plus_r12_Offset[] = {
  0x0c, 0x00, 0x98, 0xe7 // ldr al r0 r8 plus r12 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r6_Offset[] = {
  0x06, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r4_Offset[] = {
  0x04, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r9_Offset[] = {
  0x09, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r11_Offset[] = {
  0x0b, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r11 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r1_Offset[] = {
  0x01, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r14_Offset[] = {
  0x0e, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r0_Offset[] = {
  0x00, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r0 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r14_Offset[] = {
  0x0e, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r8_Offset[] = {
  0x08, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r7_plus_r0_Offset[] = {
  0x00, 0x00, 0x97, 0xe7 // ldr al r0 r7 plus r0 Offset
};
const byte kInstruction_ldr_al_r0_r10_plus_r7_Offset[] = {
  0x07, 0x00, 0x9a, 0xe7 // ldr al r0 r10 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r0_Offset[] = {
  0x00, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r4_Offset[] = {
  0x04, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r5_Offset[] = {
  0x05, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r5 Offset
};
const byte kInstruction_ldr_al_r0_r3_minus_r7_Offset[] = {
  0x07, 0x00, 0x13, 0xe7 // ldr al r0 r3 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r2_Offset[] = {
  0x02, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r4_minus_r8_Offset[] = {
  0x08, 0x00, 0x14, 0xe7 // ldr al r0 r4 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r14_Offset[] = {
  0x0e, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r14 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r2_Offset[] = {
  0x02, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r6_Offset[] = {
  0x06, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r2_minus_r4_Offset[] = {
  0x04, 0x00, 0x12, 0xe7 // ldr al r0 r2 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r0_Offset[] = {
  0x00, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r0 Offset
};
const byte kInstruction_ldr_al_r0_r14_plus_r6_Offset[] = {
  0x06, 0x00, 0x9e, 0xe7 // ldr al r0 r14 plus r6 Offset
};
const byte kInstruction_ldr_al_r0_r1_plus_r0_Offset[] = {
  0x00, 0x00, 0x91, 0xe7 // ldr al r0 r1 plus r0 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r3_Offset[] = {
  0x03, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r3 Offset
};
const byte kInstruction_ldr_al_r0_r5_plus_r4_Offset[] = {
  0x04, 0x00, 0x95, 0xe7 // ldr al r0 r5 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r7_Offset[] = {
  0x07, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r9_Offset[] = {
  0x09, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r9 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r1_Offset[] = {
  0x01, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r10_Offset[] = {
  0x0a, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r4_Offset[] = {
  0x04, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r12_Offset[] = {
  0x0c, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r12 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r5_Offset[] = {
  0x05, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r5 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r5_Offset[] = {
  0x05, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r14_Offset[] = {
  0x0e, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r14 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r14_Offset[] = {
  0x0e, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r13_Offset[] = {
  0x0d, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r10_plus_r5_Offset[] = {
  0x05, 0x00, 0x9a, 0xe7 // ldr al r0 r10 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r4_Offset[] = {
  0x04, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r10_Offset[] = {
  0x0a, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r7_plus_r5_Offset[] = {
  0x05, 0x00, 0x97, 0xe7 // ldr al r0 r7 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r5_Offset[] = {
  0x05, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r5 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r12_Offset[] = {
  0x0c, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r12 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r13_Offset[] = {
  0x0d, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r3_minus_r13_Offset[] = {
  0x0d, 0x00, 0x13, 0xe7 // ldr al r0 r3 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r8_Offset[] = {
  0x08, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r8 Offset
};
const byte kInstruction_ldr_al_r0_r0_plus_r2_Offset[] = {
  0x02, 0x00, 0x90, 0xe7 // ldr al r0 r0 plus r2 Offset
};
const byte kInstruction_ldr_al_r0_r8_plus_r1_Offset[] = {
  0x01, 0x00, 0x98, 0xe7 // ldr al r0 r8 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r2_Offset[] = {
  0x02, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r14_Offset[] = {
  0x0e, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r3_plus_r14_Offset[] = {
  0x0e, 0x00, 0x93, 0xe7 // ldr al r0 r3 plus r14 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r3_Offset[] = {
  0x03, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r3 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r9_Offset[] = {
  0x09, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r9 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r5_Offset[] = {
  0x05, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r5 Offset
};
const byte kInstruction_ldr_al_r0_r10_plus_r14_Offset[] = {
  0x0e, 0x00, 0x9a, 0xe7 // ldr al r0 r10 plus r14 Offset
};
const byte kInstruction_ldr_al_r0_r1_plus_r12_Offset[] = {
  0x0c, 0x00, 0x91, 0xe7 // ldr al r0 r1 plus r12 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r1_Offset[] = {
  0x01, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r12_Offset[] = {
  0x0c, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r12 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r2_Offset[] = {
  0x02, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r2 Offset
};
const byte kInstruction_ldr_al_r0_r11_minus_r8_Offset[] = {
  0x08, 0x00, 0x1b, 0xe7 // ldr al r0 r11 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r3_Offset[] = {
  0x03, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r9_Offset[] = {
  0x09, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r9 Offset
};
const byte kInstruction_ldr_al_r0_r11_minus_r7_Offset[] = {
  0x07, 0x00, 0x1b, 0xe7 // ldr al r0 r11 minus r7 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r1_Offset[] = {
  0x01, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r6_plus_r1_Offset[] = {
  0x01, 0x00, 0x96, 0xe7 // ldr al r0 r6 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r7_plus_r9_Offset[] = {
  0x09, 0x00, 0x97, 0xe7 // ldr al r0 r7 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r4_Offset[] = {
  0x04, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r5_Offset[] = {
  0x05, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r3_Offset[] = {
  0x03, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r3_plus_r5_Offset[] = {
  0x05, 0x00, 0x93, 0xe7 // ldr al r0 r3 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r4_Offset[] = {
  0x04, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r4 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r8_Offset[] = {
  0x08, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r8 Offset
};
const byte kInstruction_ldr_al_r0_r12_minus_r5_Offset[] = {
  0x05, 0x00, 0x1c, 0xe7 // ldr al r0 r12 minus r5 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r6_Offset[] = {
  0x06, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r8_plus_r10_Offset[] = {
  0x0a, 0x00, 0x98, 0xe7 // ldr al r0 r8 plus r10 Offset
};
const byte kInstruction_ldr_al_r0_r0_plus_r7_Offset[] = {
  0x07, 0x00, 0x90, 0xe7 // ldr al r0 r0 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r11_minus_r2_Offset[] = {
  0x02, 0x00, 0x1b, 0xe7 // ldr al r0 r11 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r7_plus_r11_Offset[] = {
  0x0b, 0x00, 0x97, 0xe7 // ldr al r0 r7 plus r11 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r3_Offset[] = {
  0x03, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r10_plus_r9_Offset[] = {
  0x09, 0x00, 0x9a, 0xe7 // ldr al r0 r10 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r2_Offset[] = {
  0x02, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r2 Offset
};
const byte kInstruction_ldr_al_r0_r12_plus_r7_Offset[] = {
  0x07, 0x00, 0x9c, 0xe7 // ldr al r0 r12 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r5_minus_r14_Offset[] = {
  0x0e, 0x00, 0x15, 0xe7 // ldr al r0 r5 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r6_minus_r14_Offset[] = {
  0x0e, 0x00, 0x16, 0xe7 // ldr al r0 r6 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r3_Offset[] = {
  0x03, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r6_Offset[] = {
  0x06, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r6 Offset
};
const byte kInstruction_ldr_al_r0_r10_plus_r2_Offset[] = {
  0x02, 0x00, 0x9a, 0xe7 // ldr al r0 r10 plus r2 Offset
};
const byte kInstruction_ldr_al_r0_r5_plus_r9_Offset[] = {
  0x09, 0x00, 0x95, 0xe7 // ldr al r0 r5 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r13_plus_r6_Offset[] = {
  0x06, 0x00, 0x9d, 0xe7 // ldr al r0 r13 plus r6 Offset
};
const byte kInstruction_ldr_al_r0_r8_minus_r0_Offset[] = {
  0x00, 0x00, 0x18, 0xe7 // ldr al r0 r8 minus r0 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r14_Offset[] = {
  0x0e, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r14 Offset
};
const byte kInstruction_ldr_al_r0_r6_plus_r13_Offset[] = {
  0x0d, 0x00, 0x96, 0xe7 // ldr al r0 r6 plus r13 Offset
};
const byte kInstruction_ldr_al_r0_r3_minus_r11_Offset[] = {
  0x0b, 0x00, 0x13, 0xe7 // ldr al r0 r3 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r11_plus_r4_Offset[] = {
  0x04, 0x00, 0x9b, 0xe7 // ldr al r0 r11 plus r4 Offset
};
const byte kInstruction_ldr_al_r0_r2_minus_r3_Offset[] = {
  0x03, 0x00, 0x12, 0xe7 // ldr al r0 r2 minus r3 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r13_Offset[] = {
  0x0d, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r2_plus_r5_Offset[] = {
  0x05, 0x00, 0x92, 0xe7 // ldr al r0 r2 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r10_Offset[] = {
  0x0a, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r10 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r0_Offset[] = {
  0x00, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r0 Offset
};
const byte kInstruction_ldr_al_r0_r0_minus_r6_Offset[] = {
  0x06, 0x00, 0x10, 0xe7 // ldr al r0 r0 minus r6 Offset
};
const byte kInstruction_ldr_al_r0_r1_plus_r7_Offset[] = {
  0x07, 0x00, 0x91, 0xe7 // ldr al r0 r1 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r13_minus_r11_Offset[] = {
  0x0b, 0x00, 0x1d, 0xe7 // ldr al r0 r13 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r7_minus_r11_Offset[] = {
  0x0b, 0x00, 0x17, 0xe7 // ldr al r0 r7 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r13_Offset[] = {
  0x0d, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r13 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r1_Offset[] = {
  0x01, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r1 Offset
};
const byte kInstruction_ldr_al_r0_r10_plus_r12_Offset[] = {
  0x0c, 0x00, 0x9a, 0xe7 // ldr al r0 r10 plus r12 Offset
};
const byte kInstruction_ldr_al_r0_r14_minus_r11_Offset[] = {
  0x0b, 0x00, 0x1e, 0xe7 // ldr al r0 r14 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r11_minus_r11_Offset[] = {
  0x0b, 0x00, 0x1b, 0xe7 // ldr al r0 r11 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r8_plus_r9_Offset[] = {
  0x09, 0x00, 0x98, 0xe7 // ldr al r0 r8 plus r9 Offset
};
const byte kInstruction_ldr_al_r0_r8_plus_r5_Offset[] = {
  0x05, 0x00, 0x98, 0xe7 // ldr al r0 r8 plus r5 Offset
};
const byte kInstruction_ldr_al_r0_r0_plus_r11_Offset[] = {
  0x0b, 0x00, 0x90, 0xe7 // ldr al r0 r0 plus r11 Offset
};
const byte kInstruction_ldr_al_r0_r7_plus_r3_Offset[] = {
  0x03, 0x00, 0x97, 0xe7 // ldr al r0 r7 plus r3 Offset
};
const byte kInstruction_ldr_al_r0_r3_minus_r1_Offset[] = {
  0x01, 0x00, 0x13, 0xe7 // ldr al r0 r3 minus r1 Offset
};
const byte kInstruction_ldr_al_r0_r10_minus_r11_Offset[] = {
  0x0b, 0x00, 0x1a, 0xe7 // ldr al r0 r10 minus r11 Offset
};
const byte kInstruction_ldr_al_r0_r4_plus_r2_Offset[] = {
  0x02, 0x00, 0x94, 0xe7 // ldr al r0 r4 plus r2 Offset
};
const byte kInstruction_ldr_al_r0_r9_plus_r7_Offset[] = {
  0x07, 0x00, 0x99, 0xe7 // ldr al r0 r9 plus r7 Offset
};
const byte kInstruction_ldr_al_r0_r9_minus_r9_Offset[] = {
  0x09, 0x00, 0x19, 0xe7 // ldr al r0 r9 minus r9 Offset
};
const byte kInstruction_ldr_al_r0_r1_minus_r9_Offset[] = {
  0x09, 0x00, 0x11, 0xe7 // ldr al r0 r1 minus r9 Offset
};
const byte kInstruction_ldr_al_r2_r5_plus_r9_PreIndex[] = {
  0x09, 0x20, 0xb5, 0xe7 // ldr al r2 r5 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r8_r14_plus_r9_PreIndex[] = {
  0x09, 0x80, 0xbe, 0xe7 // ldr al r8 r14 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r2_r10_minus_r3_PreIndex[] = {
  0x03, 0x20, 0x3a, 0xe7 // ldr al r2 r10 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r9_r4_plus_r7_PostIndex[] = {
  0x07, 0x90, 0x94, 0xe6 // ldr al r9 r4 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r1_r2_plus_r4_PreIndex[] = {
  0x04, 0x10, 0xb2, 0xe7 // ldr al r1 r2 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r5_r9_minus_r14_PostIndex[] = {
  0x0e, 0x50, 0x19, 0xe6 // ldr al r5 r9 minus r14 PostIndex
};
const byte kInstruction_ldr_al_r1_r8_plus_r6_PreIndex[] = {
  0x06, 0x10, 0xb8, 0xe7 // ldr al r1 r8 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r13_r1_minus_r7_PreIndex[] = {
  0x07, 0xd0, 0x31, 0xe7 // ldr al r13 r1 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r14_r7_minus_r5_PostIndex[] = {
  0x05, 0xe0, 0x17, 0xe6 // ldr al r14 r7 minus r5 PostIndex
};
const byte kInstruction_ldr_al_r1_r11_plus_r14_PostIndex[] = {
  0x0e, 0x10, 0x9b, 0xe6 // ldr al r1 r11 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r10_r14_minus_r6_PreIndex[] = {
  0x06, 0xa0, 0x3e, 0xe7 // ldr al r10 r14 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r1_r13_plus_r11_PostIndex[] = {
  0x0b, 0x10, 0x9d, 0xe6 // ldr al r1 r13 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r6_r12_minus_r7_PostIndex[] = {
  0x07, 0x60, 0x1c, 0xe6 // ldr al r6 r12 minus r7 PostIndex
};
const byte kInstruction_ldr_al_r8_r9_minus_r1_PreIndex[] = {
  0x01, 0x80, 0x39, 0xe7 // ldr al r8 r9 minus r1 PreIndex
};
const byte kInstruction_ldr_al_r2_r11_plus_r4_PostIndex[] = {
  0x04, 0x20, 0x9b, 0xe6 // ldr al r2 r11 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r7_r8_minus_r8_PreIndex[] = {
  0x08, 0x70, 0x38, 0xe7 // ldr al r7 r8 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r5_r9_plus_r13_PreIndex[] = {
  0x0d, 0x50, 0xb9, 0xe7 // ldr al r5 r9 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r1_r6_minus_r6_PostIndex[] = {
  0x06, 0x10, 0x16, 0xe6 // ldr al r1 r6 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r11_r0_plus_r11_PreIndex[] = {
  0x0b, 0xb0, 0xb0, 0xe7 // ldr al r11 r0 plus r11 PreIndex
};
const byte kInstruction_ldr_al_r1_r4_minus_r10_PreIndex[] = {
  0x0a, 0x10, 0x34, 0xe7 // ldr al r1 r4 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r10_r3_minus_r1_PreIndex[] = {
  0x01, 0xa0, 0x33, 0xe7 // ldr al r10 r3 minus r1 PreIndex
};
const byte kInstruction_ldr_al_r11_r14_minus_r10_PreIndex[] = {
  0x0a, 0xb0, 0x3e, 0xe7 // ldr al r11 r14 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r11_r4_plus_r4_PreIndex[] = {
  0x04, 0xb0, 0xb4, 0xe7 // ldr al r11 r4 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r8_r4_minus_r7_PreIndex[] = {
  0x07, 0x80, 0x34, 0xe7 // ldr al r8 r4 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r2_r11_plus_r8_PreIndex[] = {
  0x08, 0x20, 0xbb, 0xe7 // ldr al r2 r11 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r12_r10_minus_r7_PreIndex[] = {
  0x07, 0xc0, 0x3a, 0xe7 // ldr al r12 r10 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r14_r2_minus_r7_PreIndex[] = {
  0x07, 0xe0, 0x32, 0xe7 // ldr al r14 r2 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r2_r4_minus_r8_PreIndex[] = {
  0x08, 0x20, 0x34, 0xe7 // ldr al r2 r4 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r8_r6_plus_r13_PreIndex[] = {
  0x0d, 0x80, 0xb6, 0xe7 // ldr al r8 r6 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r9_r13_plus_r3_PostIndex[] = {
  0x03, 0x90, 0x9d, 0xe6 // ldr al r9 r13 plus r3 PostIndex
};
const byte kInstruction_ldr_al_r7_r11_plus_r13_PostIndex[] = {
  0x0d, 0x70, 0x9b, 0xe6 // ldr al r7 r11 plus r13 PostIndex
};
const byte kInstruction_ldr_al_r1_r9_minus_r9_PostIndex[] = {
  0x09, 0x10, 0x19, 0xe6 // ldr al r1 r9 minus r9 PostIndex
};
const byte kInstruction_ldr_al_r5_r8_minus_r11_PostIndex[] = {
  0x0b, 0x50, 0x18, 0xe6 // ldr al r5 r8 minus r11 PostIndex
};
const byte kInstruction_ldr_al_r0_r10_minus_r6_PreIndex[] = {
  0x06, 0x00, 0x3a, 0xe7 // ldr al r0 r10 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r11_r14_minus_r6_PostIndex[] = {
  0x06, 0xb0, 0x1e, 0xe6 // ldr al r11 r14 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r5_r8_minus_r10_PreIndex[] = {
  0x0a, 0x50, 0x38, 0xe7 // ldr al r5 r8 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r9_r10_minus_r10_PreIndex[] = {
  0x0a, 0x90, 0x3a, 0xe7 // ldr al r9 r10 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r1_r4_plus_r6_PreIndex[] = {
  0x06, 0x10, 0xb4, 0xe7 // ldr al r1 r4 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r11_r10_minus_r2_PreIndex[] = {
  0x02, 0xb0, 0x3a, 0xe7 // ldr al r11 r10 minus r2 PreIndex
};
const byte kInstruction_ldr_al_r3_r2_minus_r6_PostIndex[] = {
  0x06, 0x30, 0x12, 0xe6 // ldr al r3 r2 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r4_r1_plus_r13_PreIndex[] = {
  0x0d, 0x40, 0xb1, 0xe7 // ldr al r4 r1 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r2_r7_plus_r3_PostIndex[] = {
  0x03, 0x20, 0x97, 0xe6 // ldr al r2 r7 plus r3 PostIndex
};
const byte kInstruction_ldr_al_r4_r9_minus_r8_PostIndex[] = {
  0x08, 0x40, 0x19, 0xe6 // ldr al r4 r9 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r1_r8_plus_r11_PostIndex[] = {
  0x0b, 0x10, 0x98, 0xe6 // ldr al r1 r8 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r0_r2_minus_r7_PostIndex[] = {
  0x07, 0x00, 0x12, 0xe6 // ldr al r0 r2 minus r7 PostIndex
};
const byte kInstruction_ldr_al_r6_r5_plus_r12_PreIndex[] = {
  0x0c, 0x60, 0xb5, 0xe7 // ldr al r6 r5 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r0_r3_plus_r0_PreIndex[] = {
  0x00, 0x00, 0xb3, 0xe7 // ldr al r0 r3 plus r0 PreIndex
};
const byte kInstruction_ldr_al_r5_r4_plus_r8_PostIndex[] = {
  0x08, 0x50, 0x94, 0xe6 // ldr al r5 r4 plus r8 PostIndex
};
const byte kInstruction_ldr_al_r6_r0_plus_r6_PostIndex[] = {
  0x06, 0x60, 0x90, 0xe6 // ldr al r6 r0 plus r6 PostIndex
};
const byte kInstruction_ldr_al_r1_r12_plus_r9_PreIndex[] = {
  0x09, 0x10, 0xbc, 0xe7 // ldr al r1 r12 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r1_r6_plus_r11_PreIndex[] = {
  0x0b, 0x10, 0xb6, 0xe7 // ldr al r1 r6 plus r11 PreIndex
};
const byte kInstruction_ldr_al_r6_r8_minus_r6_PostIndex[] = {
  0x06, 0x60, 0x18, 0xe6 // ldr al r6 r8 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r3_r2_plus_r14_PreIndex[] = {
  0x0e, 0x30, 0xb2, 0xe7 // ldr al r3 r2 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r9_r0_minus_r6_PreIndex[] = {
  0x06, 0x90, 0x30, 0xe7 // ldr al r9 r0 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r7_r2_minus_r2_PreIndex[] = {
  0x02, 0x70, 0x32, 0xe7 // ldr al r7 r2 minus r2 PreIndex
};
const byte kInstruction_ldr_al_r13_r0_plus_r12_PreIndex[] = {
  0x0c, 0xd0, 0xb0, 0xe7 // ldr al r13 r0 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r7_r14_minus_r3_PreIndex[] = {
  0x03, 0x70, 0x3e, 0xe7 // ldr al r7 r14 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r1_r3_plus_r13_PreIndex[] = {
  0x0d, 0x10, 0xb3, 0xe7 // ldr al r1 r3 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r0_r4_plus_r8_PostIndex[] = {
  0x08, 0x00, 0x94, 0xe6 // ldr al r0 r4 plus r8 PostIndex
};
const byte kInstruction_ldr_al_r0_r11_minus_r2_PostIndex[] = {
  0x02, 0x00, 0x1b, 0xe6 // ldr al r0 r11 minus r2 PostIndex
};
const byte kInstruction_ldr_al_r9_r6_minus_r12_PreIndex[] = {
  0x0c, 0x90, 0x36, 0xe7 // ldr al r9 r6 minus r12 PreIndex
};
const byte kInstruction_ldr_al_r8_r12_minus_r9_PreIndex[] = {
  0x09, 0x80, 0x3c, 0xe7 // ldr al r8 r12 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r12_r10_minus_r11_PreIndex[] = {
  0x0b, 0xc0, 0x3a, 0xe7 // ldr al r12 r10 minus r11 PreIndex
};
const byte kInstruction_ldr_al_r10_r7_plus_r1_PostIndex[] = {
  0x01, 0xa0, 0x97, 0xe6 // ldr al r10 r7 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r8_r14_minus_r6_PreIndex[] = {
  0x06, 0x80, 0x3e, 0xe7 // ldr al r8 r14 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r6_r8_minus_r2_PostIndex[] = {
  0x02, 0x60, 0x18, 0xe6 // ldr al r6 r8 minus r2 PostIndex
};
const byte kInstruction_ldr_al_r10_r9_plus_r5_PostIndex[] = {
  0x05, 0xa0, 0x99, 0xe6 // ldr al r10 r9 plus r5 PostIndex
};
const byte kInstruction_ldr_al_r5_r12_minus_r4_PreIndex[] = {
  0x04, 0x50, 0x3c, 0xe7 // ldr al r5 r12 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r5_r4_plus_r4_PreIndex[] = {
  0x04, 0x50, 0xb4, 0xe7 // ldr al r5 r4 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r8_r9_minus_r3_PreIndex[] = {
  0x03, 0x80, 0x39, 0xe7 // ldr al r8 r9 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r7_r11_minus_r5_PreIndex[] = {
  0x05, 0x70, 0x3b, 0xe7 // ldr al r7 r11 minus r5 PreIndex
};
const byte kInstruction_ldr_al_r9_r6_minus_r6_PostIndex[] = {
  0x06, 0x90, 0x16, 0xe6 // ldr al r9 r6 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r11_r5_plus_r3_PreIndex[] = {
  0x03, 0xb0, 0xb5, 0xe7 // ldr al r11 r5 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r9_r0_minus_r4_PreIndex[] = {
  0x04, 0x90, 0x30, 0xe7 // ldr al r9 r0 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r0_r12_plus_r1_PostIndex[] = {
  0x01, 0x00, 0x9c, 0xe6 // ldr al r0 r12 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r1_r0_minus_r6_PreIndex[] = {
  0x06, 0x10, 0x30, 0xe7 // ldr al r1 r0 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r10_r0_minus_r5_PreIndex[] = {
  0x05, 0xa0, 0x30, 0xe7 // ldr al r10 r0 minus r5 PreIndex
};
const byte kInstruction_ldr_al_r8_r4_plus_r3_PreIndex[] = {
  0x03, 0x80, 0xb4, 0xe7 // ldr al r8 r4 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r14_r12_minus_r5_PreIndex[] = {
  0x05, 0xe0, 0x3c, 0xe7 // ldr al r14 r12 minus r5 PreIndex
};
const byte kInstruction_ldr_al_r4_r13_minus_r9_PreIndex[] = {
  0x09, 0x40, 0x3d, 0xe7 // ldr al r4 r13 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r8_r13_minus_r4_PreIndex[] = {
  0x04, 0x80, 0x3d, 0xe7 // ldr al r8 r13 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r11_r6_minus_r8_PostIndex[] = {
  0x08, 0xb0, 0x16, 0xe6 // ldr al r11 r6 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r9_r5_plus_r9_PostIndex[] = {
  0x09, 0x90, 0x95, 0xe6 // ldr al r9 r5 plus r9 PostIndex
};
const byte kInstruction_ldr_al_r9_r4_minus_r6_PreIndex[] = {
  0x06, 0x90, 0x34, 0xe7 // ldr al r9 r4 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r4_r9_minus_r13_PreIndex[] = {
  0x0d, 0x40, 0x39, 0xe7 // ldr al r4 r9 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r2_r10_plus_r10_PreIndex[] = {
  0x0a, 0x20, 0xba, 0xe7 // ldr al r2 r10 plus r10 PreIndex
};
const byte kInstruction_ldr_al_r11_r8_plus_r4_PreIndex[] = {
  0x04, 0xb0, 0xb8, 0xe7 // ldr al r11 r8 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r7_r1_minus_r0_PreIndex[] = {
  0x00, 0x70, 0x31, 0xe7 // ldr al r7 r1 minus r0 PreIndex
};
const byte kInstruction_ldr_al_r5_r10_plus_r12_PreIndex[] = {
  0x0c, 0x50, 0xba, 0xe7 // ldr al r5 r10 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r0_r5_minus_r9_PostIndex[] = {
  0x09, 0x00, 0x15, 0xe6 // ldr al r0 r5 minus r9 PostIndex
};
const byte kInstruction_ldr_al_r14_r7_minus_r7_PostIndex[] = {
  0x07, 0xe0, 0x17, 0xe6 // ldr al r14 r7 minus r7 PostIndex
};
const byte kInstruction_ldr_al_r12_r0_minus_r12_PostIndex[] = {
  0x0c, 0xc0, 0x10, 0xe6 // ldr al r12 r0 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r0_r13_minus_r13_PreIndex[] = {
  0x0d, 0x00, 0x3d, 0xe7 // ldr al r0 r13 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r9_r7_minus_r4_PostIndex[] = {
  0x04, 0x90, 0x17, 0xe6 // ldr al r9 r7 minus r4 PostIndex
};
const byte kInstruction_ldr_al_r7_r10_minus_r0_PostIndex[] = {
  0x00, 0x70, 0x1a, 0xe6 // ldr al r7 r10 minus r0 PostIndex
};
const byte kInstruction_ldr_al_r7_r0_plus_r11_PostIndex[] = {
  0x0b, 0x70, 0x90, 0xe6 // ldr al r7 r0 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r2_r8_plus_r9_PreIndex[] = {
  0x09, 0x20, 0xb8, 0xe7 // ldr al r2 r8 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r12_r14_plus_r2_PreIndex[] = {
  0x02, 0xc0, 0xbe, 0xe7 // ldr al r12 r14 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r3_r6_minus_r8_PostIndex[] = {
  0x08, 0x30, 0x16, 0xe6 // ldr al r3 r6 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r10_r11_plus_r8_PreIndex[] = {
  0x08, 0xa0, 0xbb, 0xe7 // ldr al r10 r11 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r0_r7_minus_r8_PostIndex[] = {
  0x08, 0x00, 0x17, 0xe6 // ldr al r0 r7 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r14_r9_plus_r1_PostIndex[] = {
  0x01, 0xe0, 0x99, 0xe6 // ldr al r14 r9 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r0_r9_plus_r9_PostIndex[] = {
  0x09, 0x00, 0x99, 0xe6 // ldr al r0 r9 plus r9 PostIndex
};
const byte kInstruction_ldr_al_r3_r2_plus_r14_PostIndex[] = {
  0x0e, 0x30, 0x92, 0xe6 // ldr al r3 r2 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r3_r5_plus_r12_PostIndex[] = {
  0x0c, 0x30, 0x95, 0xe6 // ldr al r3 r5 plus r12 PostIndex
};
const byte kInstruction_ldr_al_r9_r5_plus_r4_PreIndex[] = {
  0x04, 0x90, 0xb5, 0xe7 // ldr al r9 r5 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r7_r11_minus_r5_PostIndex[] = {
  0x05, 0x70, 0x1b, 0xe6 // ldr al r7 r11 minus r5 PostIndex
};
const byte kInstruction_ldr_al_r0_r4_plus_r13_PreIndex[] = {
  0x0d, 0x00, 0xb4, 0xe7 // ldr al r0 r4 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r2_r4_plus_r10_PreIndex[] = {
  0x0a, 0x20, 0xb4, 0xe7 // ldr al r2 r4 plus r10 PreIndex
};
const byte kInstruction_ldr_al_r14_r9_plus_r2_PostIndex[] = {
  0x02, 0xe0, 0x99, 0xe6 // ldr al r14 r9 plus r2 PostIndex
};
const byte kInstruction_ldr_al_r10_r9_plus_r1_PostIndex[] = {
  0x01, 0xa0, 0x99, 0xe6 // ldr al r10 r9 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r0_r13_minus_r6_PreIndex[] = {
  0x06, 0x00, 0x3d, 0xe7 // ldr al r0 r13 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r2_r0_minus_r10_PostIndex[] = {
  0x0a, 0x20, 0x10, 0xe6 // ldr al r2 r0 minus r10 PostIndex
};
const byte kInstruction_ldr_al_r0_r10_minus_r3_PreIndex[] = {
  0x03, 0x00, 0x3a, 0xe7 // ldr al r0 r10 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r1_r7_minus_r9_PreIndex[] = {
  0x09, 0x10, 0x37, 0xe7 // ldr al r1 r7 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r13_r6_minus_r11_PostIndex[] = {
  0x0b, 0xd0, 0x16, 0xe6 // ldr al r13 r6 minus r11 PostIndex
};
const byte kInstruction_ldr_al_r4_r6_plus_r12_PreIndex[] = {
  0x0c, 0x40, 0xb6, 0xe7 // ldr al r4 r6 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r12_r7_minus_r2_PostIndex[] = {
  0x02, 0xc0, 0x17, 0xe6 // ldr al r12 r7 minus r2 PostIndex
};
const byte kInstruction_ldr_al_r11_r9_minus_r6_PreIndex[] = {
  0x06, 0xb0, 0x39, 0xe7 // ldr al r11 r9 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r13_r11_minus_r8_PostIndex[] = {
  0x08, 0xd0, 0x1b, 0xe6 // ldr al r13 r11 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r13_r3_minus_r13_PreIndex[] = {
  0x0d, 0xd0, 0x33, 0xe7 // ldr al r13 r3 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r2_r9_plus_r1_PostIndex[] = {
  0x01, 0x20, 0x99, 0xe6 // ldr al r2 r9 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r9_r2_minus_r12_PostIndex[] = {
  0x0c, 0x90, 0x12, 0xe6 // ldr al r9 r2 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r10_r0_minus_r9_PreIndex[] = {
  0x09, 0xa0, 0x30, 0xe7 // ldr al r10 r0 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r4_r11_minus_r3_PreIndex[] = {
  0x03, 0x40, 0x3b, 0xe7 // ldr al r4 r11 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r2_r7_plus_r12_PreIndex[] = {
  0x0c, 0x20, 0xb7, 0xe7 // ldr al r2 r7 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r14_r2_plus_r0_PreIndex[] = {
  0x00, 0xe0, 0xb2, 0xe7 // ldr al r14 r2 plus r0 PreIndex
};
const byte kInstruction_ldr_al_r13_r4_minus_r2_PreIndex[] = {
  0x02, 0xd0, 0x34, 0xe7 // ldr al r13 r4 minus r2 PreIndex
};
const byte kInstruction_ldr_al_r13_r6_plus_r13_PreIndex[] = {
  0x0d, 0xd0, 0xb6, 0xe7 // ldr al r13 r6 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r2_r1_minus_r4_PostIndex[] = {
  0x04, 0x20, 0x11, 0xe6 // ldr al r2 r1 minus r4 PostIndex
};
const byte kInstruction_ldr_al_r4_r2_minus_r8_PreIndex[] = {
  0x08, 0x40, 0x32, 0xe7 // ldr al r4 r2 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r0_r8_plus_r6_PostIndex[] = {
  0x06, 0x00, 0x98, 0xe6 // ldr al r0 r8 plus r6 PostIndex
};
const byte kInstruction_ldr_al_r11_r10_minus_r13_PreIndex[] = {
  0x0d, 0xb0, 0x3a, 0xe7 // ldr al r11 r10 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r10_r0_plus_r3_PreIndex[] = {
  0x03, 0xa0, 0xb0, 0xe7 // ldr al r10 r0 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r1_r6_minus_r10_PreIndex[] = {
  0x0a, 0x10, 0x36, 0xe7 // ldr al r1 r6 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r12_r2_plus_r13_PostIndex[] = {
  0x0d, 0xc0, 0x92, 0xe6 // ldr al r12 r2 plus r13 PostIndex
};
const byte kInstruction_ldr_al_r14_r2_minus_r0_PostIndex[] = {
  0x00, 0xe0, 0x12, 0xe6 // ldr al r14 r2 minus r0 PostIndex
};
const byte kInstruction_ldr_al_r4_r9_minus_r10_PreIndex[] = {
  0x0a, 0x40, 0x39, 0xe7 // ldr al r4 r9 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r8_r1_plus_r14_PostIndex[] = {
  0x0e, 0x80, 0x91, 0xe6 // ldr al r8 r1 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r14_r2_minus_r13_PostIndex[] = {
  0x0d, 0xe0, 0x12, 0xe6 // ldr al r14 r2 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r4_r5_plus_r6_PostIndex[] = {
  0x06, 0x40, 0x95, 0xe6 // ldr al r4 r5 plus r6 PostIndex
};
const byte kInstruction_ldr_al_r13_r2_minus_r0_PostIndex[] = {
  0x00, 0xd0, 0x12, 0xe6 // ldr al r13 r2 minus r0 PostIndex
};
const byte kInstruction_ldr_al_r12_r0_plus_r14_PostIndex[] = {
  0x0e, 0xc0, 0x90, 0xe6 // ldr al r12 r0 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r3_r2_plus_r8_PostIndex[] = {
  0x08, 0x30, 0x92, 0xe6 // ldr al r3 r2 plus r8 PostIndex
};
const byte kInstruction_ldr_al_r12_r2_minus_r0_PreIndex[] = {
  0x00, 0xc0, 0x32, 0xe7 // ldr al r12 r2 minus r0 PreIndex
};
const byte kInstruction_ldr_al_r14_r7_minus_r13_PostIndex[] = {
  0x0d, 0xe0, 0x17, 0xe6 // ldr al r14 r7 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r2_r12_minus_r7_PreIndex[] = {
  0x07, 0x20, 0x3c, 0xe7 // ldr al r2 r12 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r12_r10_plus_r12_PreIndex[] = {
  0x0c, 0xc0, 0xba, 0xe7 // ldr al r12 r10 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r11_r1_plus_r4_PostIndex[] = {
  0x04, 0xb0, 0x91, 0xe6 // ldr al r11 r1 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r0_r8_plus_r12_PostIndex[] = {
  0x0c, 0x00, 0x98, 0xe6 // ldr al r0 r8 plus r12 PostIndex
};
const byte kInstruction_ldr_al_r8_r13_minus_r3_PreIndex[] = {
  0x03, 0x80, 0x3d, 0xe7 // ldr al r8 r13 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r8_r4_minus_r6_PostIndex[] = {
  0x06, 0x80, 0x14, 0xe6 // ldr al r8 r4 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r0_r7_minus_r6_PreIndex[] = {
  0x06, 0x00, 0x37, 0xe7 // ldr al r0 r7 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r5_r6_plus_r2_PreIndex[] = {
  0x02, 0x50, 0xb6, 0xe7 // ldr al r5 r6 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r8_r1_minus_r4_PreIndex[] = {
  0x04, 0x80, 0x31, 0xe7 // ldr al r8 r1 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r8_r6_minus_r11_PreIndex[] = {
  0x0b, 0x80, 0x36, 0xe7 // ldr al r8 r6 minus r11 PreIndex
};
const byte kInstruction_ldr_al_r10_r5_plus_r12_PreIndex[] = {
  0x0c, 0xa0, 0xb5, 0xe7 // ldr al r10 r5 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r5_r9_plus_r6_PreIndex[] = {
  0x06, 0x50, 0xb9, 0xe7 // ldr al r5 r9 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r0_r5_plus_r7_PostIndex[] = {
  0x07, 0x00, 0x95, 0xe6 // ldr al r0 r5 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r3_r13_plus_r5_PostIndex[] = {
  0x05, 0x30, 0x9d, 0xe6 // ldr al r3 r13 plus r5 PostIndex
};
const byte kInstruction_ldr_al_r3_r14_minus_r1_PostIndex[] = {
  0x01, 0x30, 0x1e, 0xe6 // ldr al r3 r14 minus r1 PostIndex
};
const byte kInstruction_ldr_al_r0_r13_minus_r11_PostIndex[] = {
  0x0b, 0x00, 0x1d, 0xe6 // ldr al r0 r13 minus r11 PostIndex
};
const byte kInstruction_ldr_al_r3_r7_plus_r14_PreIndex[] = {
  0x0e, 0x30, 0xb7, 0xe7 // ldr al r3 r7 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r1_r8_minus_r7_PostIndex[] = {
  0x07, 0x10, 0x18, 0xe6 // ldr al r1 r8 minus r7 PostIndex
};
const byte kInstruction_ldr_al_r6_r3_minus_r1_PostIndex[] = {
  0x01, 0x60, 0x13, 0xe6 // ldr al r6 r3 minus r1 PostIndex
};
const byte kInstruction_ldr_al_r5_r8_plus_r7_PostIndex[] = {
  0x07, 0x50, 0x98, 0xe6 // ldr al r5 r8 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r3_r1_plus_r6_PostIndex[] = {
  0x06, 0x30, 0x91, 0xe6 // ldr al r3 r1 plus r6 PostIndex
};
const byte kInstruction_ldr_al_r4_r0_minus_r9_PostIndex[] = {
  0x09, 0x40, 0x10, 0xe6 // ldr al r4 r0 minus r9 PostIndex
};
const byte kInstruction_ldr_al_r14_r7_minus_r6_PostIndex[] = {
  0x06, 0xe0, 0x17, 0xe6 // ldr al r14 r7 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r3_r5_minus_r4_PreIndex[] = {
  0x04, 0x30, 0x35, 0xe7 // ldr al r3 r5 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r11_r14_plus_r14_PreIndex[] = {
  0x0e, 0xb0, 0xbe, 0xe7 // ldr al r11 r14 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r3_r14_plus_r5_PreIndex[] = {
  0x05, 0x30, 0xbe, 0xe7 // ldr al r3 r14 plus r5 PreIndex
};
const byte kInstruction_ldr_al_r1_r11_minus_r11_PreIndex[] = {
  0x0b, 0x10, 0x3b, 0xe7 // ldr al r1 r11 minus r11 PreIndex
};
const byte kInstruction_ldr_al_r11_r7_plus_r14_PostIndex[] = {
  0x0e, 0xb0, 0x97, 0xe6 // ldr al r11 r7 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r7_r9_plus_r13_PostIndex[] = {
  0x0d, 0x70, 0x99, 0xe6 // ldr al r7 r9 plus r13 PostIndex
};
const byte kInstruction_ldr_al_r3_r11_plus_r14_PostIndex[] = {
  0x0e, 0x30, 0x9b, 0xe6 // ldr al r3 r11 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r3_r6_minus_r6_PreIndex[] = {
  0x06, 0x30, 0x36, 0xe7 // ldr al r3 r6 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r2_r3_minus_r6_PreIndex[] = {
  0x06, 0x20, 0x33, 0xe7 // ldr al r2 r3 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r2_r11_plus_r1_PostIndex[] = {
  0x01, 0x20, 0x9b, 0xe6 // ldr al r2 r11 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r13_r12_plus_r10_PostIndex[] = {
  0x0a, 0xd0, 0x9c, 0xe6 // ldr al r13 r12 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r1_r2_plus_r11_PreIndex[] = {
  0x0b, 0x10, 0xb2, 0xe7 // ldr al r1 r2 plus r11 PreIndex
};
const byte kInstruction_ldr_al_r3_r12_plus_r14_PreIndex[] = {
  0x0e, 0x30, 0xbc, 0xe7 // ldr al r3 r12 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r0_r6_plus_r11_PostIndex[] = {
  0x0b, 0x00, 0x96, 0xe6 // ldr al r0 r6 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r4_r6_minus_r13_PostIndex[] = {
  0x0d, 0x40, 0x16, 0xe6 // ldr al r4 r6 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r11_r8_minus_r13_PreIndex[] = {
  0x0d, 0xb0, 0x38, 0xe7 // ldr al r11 r8 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r5_r3_minus_r6_PostIndex[] = {
  0x06, 0x50, 0x13, 0xe6 // ldr al r5 r3 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r8_r1_plus_r2_PostIndex[] = {
  0x02, 0x80, 0x91, 0xe6 // ldr al r8 r1 plus r2 PostIndex
};
const byte kInstruction_ldr_al_r11_r5_minus_r13_PreIndex[] = {
  0x0d, 0xb0, 0x35, 0xe7 // ldr al r11 r5 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r7_r9_plus_r2_PostIndex[] = {
  0x02, 0x70, 0x99, 0xe6 // ldr al r7 r9 plus r2 PostIndex
};
const byte kInstruction_ldr_al_r3_r10_plus_r11_PostIndex[] = {
  0x0b, 0x30, 0x9a, 0xe6 // ldr al r3 r10 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r0_r12_plus_r11_PreIndex[] = {
  0x0b, 0x00, 0xbc, 0xe7 // ldr al r0 r12 plus r11 PreIndex
};
const byte kInstruction_ldr_al_r7_r4_plus_r14_PostIndex[] = {
  0x0e, 0x70, 0x94, 0xe6 // ldr al r7 r4 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r11_r5_plus_r1_PreIndex[] = {
  0x01, 0xb0, 0xb5, 0xe7 // ldr al r11 r5 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r3_r2_plus_r3_PostIndex[] = {
  0x03, 0x30, 0x92, 0xe6 // ldr al r3 r2 plus r3 PostIndex
};
const byte kInstruction_ldr_al_r11_r8_minus_r4_PostIndex[] = {
  0x04, 0xb0, 0x18, 0xe6 // ldr al r11 r8 minus r4 PostIndex
};
const byte kInstruction_ldr_al_r14_r5_plus_r10_PostIndex[] = {
  0x0a, 0xe0, 0x95, 0xe6 // ldr al r14 r5 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r13_r3_minus_r3_PreIndex[] = {
  0x03, 0xd0, 0x33, 0xe7 // ldr al r13 r3 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r2_r3_minus_r8_PostIndex[] = {
  0x08, 0x20, 0x13, 0xe6 // ldr al r2 r3 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r2_r13_minus_r1_PreIndex[] = {
  0x01, 0x20, 0x3d, 0xe7 // ldr al r2 r13 minus r1 PreIndex
};
const byte kInstruction_ldr_al_r0_r13_plus_r1_PostIndex[] = {
  0x01, 0x00, 0x9d, 0xe6 // ldr al r0 r13 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r6_r5_plus_r3_PreIndex[] = {
  0x03, 0x60, 0xb5, 0xe7 // ldr al r6 r5 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r0_r3_plus_r12_PreIndex[] = {
  0x0c, 0x00, 0xb3, 0xe7 // ldr al r0 r3 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r4_r7_plus_r3_PreIndex[] = {
  0x03, 0x40, 0xb7, 0xe7 // ldr al r4 r7 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r11_r14_plus_r11_PostIndex[] = {
  0x0b, 0xb0, 0x9e, 0xe6 // ldr al r11 r14 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r0_r11_minus_r14_PreIndex[] = {
  0x0e, 0x00, 0x3b, 0xe7 // ldr al r0 r11 minus r14 PreIndex
};
const byte kInstruction_ldr_al_r11_r9_plus_r2_PostIndex[] = {
  0x02, 0xb0, 0x99, 0xe6 // ldr al r11 r9 plus r2 PostIndex
};
const byte kInstruction_ldr_al_r14_r1_minus_r12_PreIndex[] = {
  0x0c, 0xe0, 0x31, 0xe7 // ldr al r14 r1 minus r12 PreIndex
};
const byte kInstruction_ldr_al_r5_r6_plus_r1_PreIndex[] = {
  0x01, 0x50, 0xb6, 0xe7 // ldr al r5 r6 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r10_r5_minus_r3_PostIndex[] = {
  0x03, 0xa0, 0x15, 0xe6 // ldr al r10 r5 minus r3 PostIndex
};
const byte kInstruction_ldr_al_r1_r4_plus_r8_PreIndex[] = {
  0x08, 0x10, 0xb4, 0xe7 // ldr al r1 r4 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r12_r14_plus_r0_PostIndex[] = {
  0x00, 0xc0, 0x9e, 0xe6 // ldr al r12 r14 plus r0 PostIndex
};
const byte kInstruction_ldr_al_r1_r0_plus_r10_PreIndex[] = {
  0x0a, 0x10, 0xb0, 0xe7 // ldr al r1 r0 plus r10 PreIndex
};
const byte kInstruction_ldr_al_r13_r11_plus_r14_PreIndex[] = {
  0x0e, 0xd0, 0xbb, 0xe7 // ldr al r13 r11 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r7_r8_plus_r13_PostIndex[] = {
  0x0d, 0x70, 0x98, 0xe6 // ldr al r7 r8 plus r13 PostIndex
};
const byte kInstruction_ldr_al_r2_r3_minus_r11_PostIndex[] = {
  0x0b, 0x20, 0x13, 0xe6 // ldr al r2 r3 minus r11 PostIndex
};
const byte kInstruction_ldr_al_r8_r11_plus_r8_PreIndex[] = {
  0x08, 0x80, 0xbb, 0xe7 // ldr al r8 r11 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r7_r13_plus_r12_PreIndex[] = {
  0x0c, 0x70, 0xbd, 0xe7 // ldr al r7 r13 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r2_r10_plus_r7_PostIndex[] = {
  0x07, 0x20, 0x9a, 0xe6 // ldr al r2 r10 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r5_r4_minus_r6_PreIndex[] = {
  0x06, 0x50, 0x34, 0xe7 // ldr al r5 r4 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r10_r2_plus_r4_PostIndex[] = {
  0x04, 0xa0, 0x92, 0xe6 // ldr al r10 r2 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r4_r9_minus_r14_PreIndex[] = {
  0x0e, 0x40, 0x39, 0xe7 // ldr al r4 r9 minus r14 PreIndex
};
const byte kInstruction_ldr_al_r3_r11_plus_r8_PostIndex[] = {
  0x08, 0x30, 0x9b, 0xe6 // ldr al r3 r11 plus r8 PostIndex
};
const byte kInstruction_ldr_al_r14_r13_minus_r8_PreIndex[] = {
  0x08, 0xe0, 0x3d, 0xe7 // ldr al r14 r13 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r5_r13_minus_r7_PreIndex[] = {
  0x07, 0x50, 0x3d, 0xe7 // ldr al r5 r13 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r5_r2_minus_r2_PreIndex[] = {
  0x02, 0x50, 0x32, 0xe7 // ldr al r5 r2 minus r2 PreIndex
};
const byte kInstruction_ldr_al_r9_r2_minus_r9_PreIndex[] = {
  0x09, 0x90, 0x32, 0xe7 // ldr al r9 r2 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r2_r7_plus_r11_PreIndex[] = {
  0x0b, 0x20, 0xb7, 0xe7 // ldr al r2 r7 plus r11 PreIndex
};
const byte kInstruction_ldr_al_r2_r6_minus_r14_PreIndex[] = {
  0x0e, 0x20, 0x36, 0xe7 // ldr al r2 r6 minus r14 PreIndex
};
const byte kInstruction_ldr_al_r7_r6_minus_r6_PreIndex[] = {
  0x06, 0x70, 0x36, 0xe7 // ldr al r7 r6 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r10_r1_minus_r13_PreIndex[] = {
  0x0d, 0xa0, 0x31, 0xe7 // ldr al r10 r1 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r7_r3_minus_r13_PostIndex[] = {
  0x0d, 0x70, 0x13, 0xe6 // ldr al r7 r3 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r3_r1_minus_r8_PreIndex[] = {
  0x08, 0x30, 0x31, 0xe7 // ldr al r3 r1 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r13_r1_plus_r12_PostIndex[] = {
  0x0c, 0xd0, 0x91, 0xe6 // ldr al r13 r1 plus r12 PostIndex
};
const byte kInstruction_ldr_al_r13_r14_plus_r3_PostIndex[] = {
  0x03, 0xd0, 0x9e, 0xe6 // ldr al r13 r14 plus r3 PostIndex
};
const byte kInstruction_ldr_al_r9_r5_plus_r7_PostIndex[] = {
  0x07, 0x90, 0x95, 0xe6 // ldr al r9 r5 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r3_r2_plus_r8_PreIndex[] = {
  0x08, 0x30, 0xb2, 0xe7 // ldr al r3 r2 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r1_r8_minus_r9_PostIndex[] = {
  0x09, 0x10, 0x18, 0xe6 // ldr al r1 r8 minus r9 PostIndex
};
const byte kInstruction_ldr_al_r11_r14_minus_r8_PostIndex[] = {
  0x08, 0xb0, 0x1e, 0xe6 // ldr al r11 r14 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r2_r12_minus_r6_PostIndex[] = {
  0x06, 0x20, 0x1c, 0xe6 // ldr al r2 r12 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r4_r1_minus_r12_PostIndex[] = {
  0x0c, 0x40, 0x11, 0xe6 // ldr al r4 r1 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r13_r6_minus_r13_PreIndex[] = {
  0x0d, 0xd0, 0x36, 0xe7 // ldr al r13 r6 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r5_r9_minus_r13_PostIndex[] = {
  0x0d, 0x50, 0x19, 0xe6 // ldr al r5 r9 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r4_r8_minus_r12_PostIndex[] = {
  0x0c, 0x40, 0x18, 0xe6 // ldr al r4 r8 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r5_r9_plus_r12_PreIndex[] = {
  0x0c, 0x50, 0xb9, 0xe7 // ldr al r5 r9 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r11_r13_minus_r3_PreIndex[] = {
  0x03, 0xb0, 0x3d, 0xe7 // ldr al r11 r13 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r4_r13_minus_r13_PreIndex[] = {
  0x0d, 0x40, 0x3d, 0xe7 // ldr al r4 r13 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r3_r7_plus_r0_PostIndex[] = {
  0x00, 0x30, 0x97, 0xe6 // ldr al r3 r7 plus r0 PostIndex
};
const byte kInstruction_ldr_al_r5_r11_minus_r8_PostIndex[] = {
  0x08, 0x50, 0x1b, 0xe6 // ldr al r5 r11 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r5_r0_minus_r0_PreIndex[] = {
  0x00, 0x50, 0x30, 0xe7 // ldr al r5 r0 minus r0 PreIndex
};
const byte kInstruction_ldr_al_r0_r1_minus_r1_PostIndex[] = {
  0x01, 0x00, 0x11, 0xe6 // ldr al r0 r1 minus r1 PostIndex
};
const byte kInstruction_ldr_al_r5_r12_minus_r0_PreIndex[] = {
  0x00, 0x50, 0x3c, 0xe7 // ldr al r5 r12 minus r0 PreIndex
};
const byte kInstruction_ldr_al_r6_r1_plus_r7_PreIndex[] = {
  0x07, 0x60, 0xb1, 0xe7 // ldr al r6 r1 plus r7 PreIndex
};
const byte kInstruction_ldr_al_r5_r13_minus_r8_PreIndex[] = {
  0x08, 0x50, 0x3d, 0xe7 // ldr al r5 r13 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r3_r8_plus_r11_PostIndex[] = {
  0x0b, 0x30, 0x98, 0xe6 // ldr al r3 r8 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r8_r0_plus_r2_PreIndex[] = {
  0x02, 0x80, 0xb0, 0xe7 // ldr al r8 r0 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r10_r14_plus_r6_PreIndex[] = {
  0x06, 0xa0, 0xbe, 0xe7 // ldr al r10 r14 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r12_r2_minus_r0_PostIndex[] = {
  0x00, 0xc0, 0x12, 0xe6 // ldr al r12 r2 minus r0 PostIndex
};
const byte kInstruction_ldr_al_r13_r0_minus_r1_PreIndex[] = {
  0x01, 0xd0, 0x30, 0xe7 // ldr al r13 r0 minus r1 PreIndex
};
const byte kInstruction_ldr_al_r12_r6_minus_r10_PreIndex[] = {
  0x0a, 0xc0, 0x36, 0xe7 // ldr al r12 r6 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r0_r7_minus_r0_PostIndex[] = {
  0x00, 0x00, 0x17, 0xe6 // ldr al r0 r7 minus r0 PostIndex
};
const byte kInstruction_ldr_al_r1_r7_minus_r3_PreIndex[] = {
  0x03, 0x10, 0x37, 0xe7 // ldr al r1 r7 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r9_r2_plus_r13_PostIndex[] = {
  0x0d, 0x90, 0x92, 0xe6 // ldr al r9 r2 plus r13 PostIndex
};
const byte kInstruction_ldr_al_r0_r11_minus_r3_PostIndex[] = {
  0x03, 0x00, 0x1b, 0xe6 // ldr al r0 r11 minus r3 PostIndex
};
const byte kInstruction_ldr_al_r2_r1_plus_r1_PreIndex[] = {
  0x01, 0x20, 0xb1, 0xe7 // ldr al r2 r1 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r5_r4_plus_r5_PostIndex[] = {
  0x05, 0x50, 0x94, 0xe6 // ldr al r5 r4 plus r5 PostIndex
};
const byte kInstruction_ldr_al_r7_r13_plus_r4_PostIndex[] = {
  0x04, 0x70, 0x9d, 0xe6 // ldr al r7 r13 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r0_r14_plus_r6_PreIndex[] = {
  0x06, 0x00, 0xbe, 0xe7 // ldr al r0 r14 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r10_r1_plus_r7_PostIndex[] = {
  0x07, 0xa0, 0x91, 0xe6 // ldr al r10 r1 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r12_r5_plus_r12_PostIndex[] = {
  0x0c, 0xc0, 0x95, 0xe6 // ldr al r12 r5 plus r12 PostIndex
};
const byte kInstruction_ldr_al_r0_r10_plus_r2_PreIndex[] = {
  0x02, 0x00, 0xba, 0xe7 // ldr al r0 r10 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r7_r13_plus_r8_PreIndex[] = {
  0x08, 0x70, 0xbd, 0xe7 // ldr al r7 r13 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r14_r10_plus_r9_PreIndex[] = {
  0x09, 0xe0, 0xba, 0xe7 // ldr al r14 r10 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r1_r2_plus_r1_PreIndex[] = {
  0x01, 0x10, 0xb2, 0xe7 // ldr al r1 r2 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r6_r7_plus_r12_PreIndex[] = {
  0x0c, 0x60, 0xb7, 0xe7 // ldr al r6 r7 plus r12 PreIndex
};
const byte kInstruction_ldr_al_r10_r1_plus_r3_PreIndex[] = {
  0x03, 0xa0, 0xb1, 0xe7 // ldr al r10 r1 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r6_r4_plus_r11_PostIndex[] = {
  0x0b, 0x60, 0x94, 0xe6 // ldr al r6 r4 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r14_r0_plus_r12_PostIndex[] = {
  0x0c, 0xe0, 0x90, 0xe6 // ldr al r14 r0 plus r12 PostIndex
};
const byte kInstruction_ldr_al_r4_r7_minus_r12_PostIndex[] = {
  0x0c, 0x40, 0x17, 0xe6 // ldr al r4 r7 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r13_r10_plus_r10_PostIndex[] = {
  0x0a, 0xd0, 0x9a, 0xe6 // ldr al r13 r10 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r9_r4_minus_r1_PreIndex[] = {
  0x01, 0x90, 0x34, 0xe7 // ldr al r9 r4 minus r1 PreIndex
};
const byte kInstruction_ldr_al_r2_r7_minus_r2_PreIndex[] = {
  0x02, 0x20, 0x37, 0xe7 // ldr al r2 r7 minus r2 PreIndex
};
const byte kInstruction_ldr_al_r10_r6_plus_r2_PreIndex[] = {
  0x02, 0xa0, 0xb6, 0xe7 // ldr al r10 r6 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r8_r14_minus_r2_PostIndex[] = {
  0x02, 0x80, 0x1e, 0xe6 // ldr al r8 r14 minus r2 PostIndex
};
const byte kInstruction_ldr_al_r4_r9_minus_r14_PostIndex[] = {
  0x0e, 0x40, 0x19, 0xe6 // ldr al r4 r9 minus r14 PostIndex
};
const byte kInstruction_ldr_al_r3_r8_plus_r12_PostIndex[] = {
  0x0c, 0x30, 0x98, 0xe6 // ldr al r3 r8 plus r12 PostIndex
};
const byte kInstruction_ldr_al_r3_r12_plus_r8_PostIndex[] = {
  0x08, 0x30, 0x9c, 0xe6 // ldr al r3 r12 plus r8 PostIndex
};
const byte kInstruction_ldr_al_r4_r6_minus_r10_PreIndex[] = {
  0x0a, 0x40, 0x36, 0xe7 // ldr al r4 r6 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r3_r14_plus_r6_PreIndex[] = {
  0x06, 0x30, 0xbe, 0xe7 // ldr al r3 r14 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r2_r1_plus_r7_PreIndex[] = {
  0x07, 0x20, 0xb1, 0xe7 // ldr al r2 r1 plus r7 PreIndex
};
const byte kInstruction_ldr_al_r7_r9_plus_r2_PreIndex[] = {
  0x02, 0x70, 0xb9, 0xe7 // ldr al r7 r9 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r11_r6_plus_r10_PostIndex[] = {
  0x0a, 0xb0, 0x96, 0xe6 // ldr al r11 r6 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r5_r2_plus_r11_PostIndex[] = {
  0x0b, 0x50, 0x92, 0xe6 // ldr al r5 r2 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r8_r10_plus_r10_PreIndex[] = {
  0x0a, 0x80, 0xba, 0xe7 // ldr al r8 r10 plus r10 PreIndex
};
const byte kInstruction_ldr_al_r8_r0_minus_r10_PreIndex[] = {
  0x0a, 0x80, 0x30, 0xe7 // ldr al r8 r0 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r0_r4_plus_r2_PreIndex[] = {
  0x02, 0x00, 0xb4, 0xe7 // ldr al r0 r4 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r3_r4_minus_r8_PreIndex[] = {
  0x08, 0x30, 0x34, 0xe7 // ldr al r3 r4 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r1_r0_minus_r11_PreIndex[] = {
  0x0b, 0x10, 0x30, 0xe7 // ldr al r1 r0 minus r11 PreIndex
};
const byte kInstruction_ldr_al_r0_r2_minus_r9_PreIndex[] = {
  0x09, 0x00, 0x32, 0xe7 // ldr al r0 r2 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r14_r12_plus_r13_PostIndex[] = {
  0x0d, 0xe0, 0x9c, 0xe6 // ldr al r14 r12 plus r13 PostIndex
};
const byte kInstruction_ldr_al_r13_r10_minus_r5_PreIndex[] = {
  0x05, 0xd0, 0x3a, 0xe7 // ldr al r13 r10 minus r5 PreIndex
};
const byte kInstruction_ldr_al_r9_r0_plus_r11_PostIndex[] = {
  0x0b, 0x90, 0x90, 0xe6 // ldr al r9 r0 plus r11 PostIndex
};
const byte kInstruction_ldr_al_r2_r11_plus_r7_PostIndex[] = {
  0x07, 0x20, 0x9b, 0xe6 // ldr al r2 r11 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r7_r5_plus_r10_PreIndex[] = {
  0x0a, 0x70, 0xb5, 0xe7 // ldr al r7 r5 plus r10 PreIndex
};
const byte kInstruction_ldr_al_r4_r3_minus_r2_PostIndex[] = {
  0x02, 0x40, 0x13, 0xe6 // ldr al r4 r3 minus r2 PostIndex
};
const byte kInstruction_ldr_al_r2_r6_minus_r6_PostIndex[] = {
  0x06, 0x20, 0x16, 0xe6 // ldr al r2 r6 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r11_r1_minus_r9_PreIndex[] = {
  0x09, 0xb0, 0x31, 0xe7 // ldr al r11 r1 minus r9 PreIndex
};
const byte kInstruction_ldr_al_r5_r13_plus_r5_PostIndex[] = {
  0x05, 0x50, 0x9d, 0xe6 // ldr al r5 r13 plus r5 PostIndex
};
const byte kInstruction_ldr_al_r1_r13_minus_r13_PostIndex[] = {
  0x0d, 0x10, 0x1d, 0xe6 // ldr al r1 r13 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r0_r10_plus_r10_PostIndex[] = {
  0x0a, 0x00, 0x9a, 0xe6 // ldr al r0 r10 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r5_r10_plus_r9_PreIndex[] = {
  0x09, 0x50, 0xba, 0xe7 // ldr al r5 r10 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r0_r13_minus_r2_PostIndex[] = {
  0x02, 0x00, 0x1d, 0xe6 // ldr al r0 r13 minus r2 PostIndex
};
const byte kInstruction_ldr_al_r7_r8_minus_r0_PostIndex[] = {
  0x00, 0x70, 0x18, 0xe6 // ldr al r7 r8 minus r0 PostIndex
};
const byte kInstruction_ldr_al_r2_r9_minus_r12_PostIndex[] = {
  0x0c, 0x20, 0x19, 0xe6 // ldr al r2 r9 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r9_r3_minus_r5_PostIndex[] = {
  0x05, 0x90, 0x13, 0xe6 // ldr al r9 r3 minus r5 PostIndex
};
const byte kInstruction_ldr_al_r6_r5_minus_r12_PostIndex[] = {
  0x0c, 0x60, 0x15, 0xe6 // ldr al r6 r5 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r11_r4_minus_r10_PreIndex[] = {
  0x0a, 0xb0, 0x34, 0xe7 // ldr al r11 r4 minus r10 PreIndex
};
const byte kInstruction_ldr_al_r10_r14_plus_r1_PostIndex[] = {
  0x01, 0xa0, 0x9e, 0xe6 // ldr al r10 r14 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r8_r5_plus_r0_PreIndex[] = {
  0x00, 0x80, 0xb5, 0xe7 // ldr al r8 r5 plus r0 PreIndex
};
const byte kInstruction_ldr_al_r10_r13_plus_r13_PreIndex[] = {
  0x0d, 0xa0, 0xbd, 0xe7 // ldr al r10 r13 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r0_r8_plus_r13_PreIndex[] = {
  0x0d, 0x00, 0xb8, 0xe7 // ldr al r0 r8 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r10_r13_plus_r8_PreIndex[] = {
  0x08, 0xa0, 0xbd, 0xe7 // ldr al r10 r13 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r11_r6_minus_r4_PreIndex[] = {
  0x04, 0xb0, 0x36, 0xe7 // ldr al r11 r6 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r1_r9_plus_r10_PostIndex[] = {
  0x0a, 0x10, 0x99, 0xe6 // ldr al r1 r9 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r3_r12_minus_r12_PostIndex[] = {
  0x0c, 0x30, 0x1c, 0xe6 // ldr al r3 r12 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r13_r6_minus_r6_PreIndex[] = {
  0x06, 0xd0, 0x36, 0xe7 // ldr al r13 r6 minus r6 PreIndex
};
const byte kInstruction_ldr_al_r9_r14_plus_r4_PostIndex[] = {
  0x04, 0x90, 0x9e, 0xe6 // ldr al r9 r14 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r12_r10_minus_r13_PostIndex[] = {
  0x0d, 0xc0, 0x1a, 0xe6 // ldr al r12 r10 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r7_r11_minus_r7_PreIndex[] = {
  0x07, 0x70, 0x3b, 0xe7 // ldr al r7 r11 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r11_r4_minus_r12_PostIndex[] = {
  0x0c, 0xb0, 0x14, 0xe6 // ldr al r11 r4 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r8_r14_plus_r8_PreIndex[] = {
  0x08, 0x80, 0xbe, 0xe7 // ldr al r8 r14 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r12_r1_plus_r14_PreIndex[] = {
  0x0e, 0xc0, 0xb1, 0xe7 // ldr al r12 r1 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r3_r4_plus_r2_PostIndex[] = {
  0x02, 0x30, 0x94, 0xe6 // ldr al r3 r4 plus r2 PostIndex
};
const byte kInstruction_ldr_al_r6_r8_minus_r5_PostIndex[] = {
  0x05, 0x60, 0x18, 0xe6 // ldr al r6 r8 minus r5 PostIndex
};
const byte kInstruction_ldr_al_r12_r14_plus_r4_PostIndex[] = {
  0x04, 0xc0, 0x9e, 0xe6 // ldr al r12 r14 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r3_r10_minus_r8_PostIndex[] = {
  0x08, 0x30, 0x1a, 0xe6 // ldr al r3 r10 minus r8 PostIndex
};
const byte kInstruction_ldr_al_r12_r7_plus_r1_PreIndex[] = {
  0x01, 0xc0, 0xb7, 0xe7 // ldr al r12 r7 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r14_r9_minus_r7_PreIndex[] = {
  0x07, 0xe0, 0x39, 0xe7 // ldr al r14 r9 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r7_r12_plus_r1_PreIndex[] = {
  0x01, 0x70, 0xbc, 0xe7 // ldr al r7 r12 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r10_r11_minus_r4_PreIndex[] = {
  0x04, 0xa0, 0x3b, 0xe7 // ldr al r10 r11 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r4_r9_minus_r3_PreIndex[] = {
  0x03, 0x40, 0x39, 0xe7 // ldr al r4 r9 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r2_r13_plus_r14_PreIndex[] = {
  0x0e, 0x20, 0xbd, 0xe7 // ldr al r2 r13 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r1_r12_minus_r13_PreIndex[] = {
  0x0d, 0x10, 0x3c, 0xe7 // ldr al r1 r12 minus r13 PreIndex
};
const byte kInstruction_ldr_al_r6_r10_plus_r6_PostIndex[] = {
  0x06, 0x60, 0x9a, 0xe6 // ldr al r6 r10 plus r6 PostIndex
};
const byte kInstruction_ldr_al_r0_r14_minus_r7_PreIndex[] = {
  0x07, 0x00, 0x3e, 0xe7 // ldr al r0 r14 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r5_r13_minus_r13_PostIndex[] = {
  0x0d, 0x50, 0x1d, 0xe6 // ldr al r5 r13 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r2_r11_minus_r6_PostIndex[] = {
  0x06, 0x20, 0x1b, 0xe6 // ldr al r2 r11 minus r6 PostIndex
};
const byte kInstruction_ldr_al_r5_r9_plus_r14_PostIndex[] = {
  0x0e, 0x50, 0x99, 0xe6 // ldr al r5 r9 plus r14 PostIndex
};
const byte kInstruction_ldr_al_r7_r2_plus_r7_PostIndex[] = {
  0x07, 0x70, 0x92, 0xe6 // ldr al r7 r2 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r9_r2_plus_r2_PreIndex[] = {
  0x02, 0x90, 0xb2, 0xe7 // ldr al r9 r2 plus r2 PreIndex
};
const byte kInstruction_ldr_al_r0_r14_plus_r14_PreIndex[] = {
  0x0e, 0x00, 0xbe, 0xe7 // ldr al r0 r14 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r14_r13_minus_r0_PreIndex[] = {
  0x00, 0xe0, 0x3d, 0xe7 // ldr al r14 r13 minus r0 PreIndex
};
const byte kInstruction_ldr_al_r7_r3_minus_r5_PreIndex[] = {
  0x05, 0x70, 0x33, 0xe7 // ldr al r7 r3 minus r5 PreIndex
};
const byte kInstruction_ldr_al_r14_r0_minus_r10_PostIndex[] = {
  0x0a, 0xe0, 0x10, 0xe6 // ldr al r14 r0 minus r10 PostIndex
};
const byte kInstruction_ldr_al_r1_r2_minus_r4_PreIndex[] = {
  0x04, 0x10, 0x32, 0xe7 // ldr al r1 r2 minus r4 PreIndex
};
const byte kInstruction_ldr_al_r8_r3_minus_r5_PostIndex[] = {
  0x05, 0x80, 0x13, 0xe6 // ldr al r8 r3 minus r5 PostIndex
};
const byte kInstruction_ldr_al_r3_r5_plus_r6_PreIndex[] = {
  0x06, 0x30, 0xb5, 0xe7 // ldr al r3 r5 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r4_r12_plus_r9_PostIndex[] = {
  0x09, 0x40, 0x9c, 0xe6 // ldr al r4 r12 plus r9 PostIndex
};
const byte kInstruction_ldr_al_r4_r12_minus_r3_PreIndex[] = {
  0x03, 0x40, 0x3c, 0xe7 // ldr al r4 r12 minus r3 PreIndex
};
const byte kInstruction_ldr_al_r12_r0_minus_r5_PostIndex[] = {
  0x05, 0xc0, 0x10, 0xe6 // ldr al r12 r0 minus r5 PostIndex
};
const byte kInstruction_ldr_al_r12_r4_plus_r7_PostIndex[] = {
  0x07, 0xc0, 0x94, 0xe6 // ldr al r12 r4 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r6_r5_minus_r7_PreIndex[] = {
  0x07, 0x60, 0x35, 0xe7 // ldr al r6 r5 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r10_r11_plus_r4_PostIndex[] = {
  0x04, 0xa0, 0x9b, 0xe6 // ldr al r10 r11 plus r4 PostIndex
};
const byte kInstruction_ldr_al_r3_r12_plus_r7_PreIndex[] = {
  0x07, 0x30, 0xbc, 0xe7 // ldr al r3 r12 plus r7 PreIndex
};
const byte kInstruction_ldr_al_r3_r10_plus_r4_PreIndex[] = {
  0x04, 0x30, 0xba, 0xe7 // ldr al r3 r10 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r6_r8_plus_r6_PreIndex[] = {
  0x06, 0x60, 0xb8, 0xe7 // ldr al r6 r8 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r4_r5_plus_r8_PostIndex[] = {
  0x08, 0x40, 0x95, 0xe6 // ldr al r4 r5 plus r8 PostIndex
};
const byte kInstruction_ldr_al_r13_r0_minus_r3_PostIndex[] = {
  0x03, 0xd0, 0x10, 0xe6 // ldr al r13 r0 minus r3 PostIndex
};
const byte kInstruction_ldr_al_r7_r2_minus_r14_PreIndex[] = {
  0x0e, 0x70, 0x32, 0xe7 // ldr al r7 r2 minus r14 PreIndex
};
const byte kInstruction_ldr_al_r3_r10_plus_r3_PostIndex[] = {
  0x03, 0x30, 0x9a, 0xe6 // ldr al r3 r10 plus r3 PostIndex
};
const byte kInstruction_ldr_al_r10_r4_minus_r1_PostIndex[] = {
  0x01, 0xa0, 0x14, 0xe6 // ldr al r10 r4 minus r1 PostIndex
};
const byte kInstruction_ldr_al_r6_r5_minus_r1_PreIndex[] = {
  0x01, 0x60, 0x35, 0xe7 // ldr al r6 r5 minus r1 PreIndex
};
const byte kInstruction_ldr_al_r7_r3_plus_r5_PostIndex[] = {
  0x05, 0x70, 0x93, 0xe6 // ldr al r7 r3 plus r5 PostIndex
};
const byte kInstruction_ldr_al_r7_r8_plus_r13_PreIndex[] = {
  0x0d, 0x70, 0xb8, 0xe7 // ldr al r7 r8 plus r13 PreIndex
};
const byte kInstruction_ldr_al_r10_r13_plus_r4_PreIndex[] = {
  0x04, 0xa0, 0xbd, 0xe7 // ldr al r10 r13 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r8_r3_plus_r1_PostIndex[] = {
  0x01, 0x80, 0x93, 0xe6 // ldr al r8 r3 plus r1 PostIndex
};
const byte kInstruction_ldr_al_r14_r6_plus_r3_PreIndex[] = {
  0x03, 0xe0, 0xb6, 0xe7 // ldr al r14 r6 plus r3 PreIndex
};
const byte kInstruction_ldr_al_r3_r5_minus_r4_PostIndex[] = {
  0x04, 0x30, 0x15, 0xe6 // ldr al r3 r5 minus r4 PostIndex
};
const byte kInstruction_ldr_al_r5_r7_plus_r6_PreIndex[] = {
  0x06, 0x50, 0xb7, 0xe7 // ldr al r5 r7 plus r6 PreIndex
};
const byte kInstruction_ldr_al_r4_r12_minus_r9_PostIndex[] = {
  0x09, 0x40, 0x1c, 0xe6 // ldr al r4 r12 minus r9 PostIndex
};
const byte kInstruction_ldr_al_r7_r3_plus_r14_PreIndex[] = {
  0x0e, 0x70, 0xb3, 0xe7 // ldr al r7 r3 plus r14 PreIndex
};
const byte kInstruction_ldr_al_r14_r8_minus_r7_PreIndex[] = {
  0x07, 0xe0, 0x38, 0xe7 // ldr al r14 r8 minus r7 PreIndex
};
const byte kInstruction_ldr_al_r2_r7_minus_r11_PreIndex[] = {
  0x0b, 0x20, 0x37, 0xe7 // ldr al r2 r7 minus r11 PreIndex
};
const byte kInstruction_ldr_al_r8_r6_plus_r7_PreIndex[] = {
  0x07, 0x80, 0xb6, 0xe7 // ldr al r8 r6 plus r7 PreIndex
};
const byte kInstruction_ldr_al_r9_r3_plus_r7_PostIndex[] = {
  0x07, 0x90, 0x93, 0xe6 // ldr al r9 r3 plus r7 PostIndex
};
const byte kInstruction_ldr_al_r7_r0_minus_r8_PreIndex[] = {
  0x08, 0x70, 0x30, 0xe7 // ldr al r7 r0 minus r8 PreIndex
};
const byte kInstruction_ldr_al_r6_r1_plus_r9_PreIndex[] = {
  0x09, 0x60, 0xb1, 0xe7 // ldr al r6 r1 plus r9 PreIndex
};
const byte kInstruction_ldr_al_r2_r13_plus_r6_PostIndex[] = {
  0x06, 0x20, 0x9d, 0xe6 // ldr al r2 r13 plus r6 PostIndex
};
const byte kInstruction_ldr_al_r11_r7_plus_r10_PostIndex[] = {
  0x0a, 0xb0, 0x97, 0xe6 // ldr al r11 r7 plus r10 PostIndex
};
const byte kInstruction_ldr_al_r9_r8_plus_r0_PostIndex[] = {
  0x00, 0x90, 0x98, 0xe6 // ldr al r9 r8 plus r0 PostIndex
};
const byte kInstruction_ldr_al_r3_r4_minus_r12_PostIndex[] = {
  0x0c, 0x30, 0x14, 0xe6 // ldr al r3 r4 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r8_r5_minus_r7_PostIndex[] = {
  0x07, 0x80, 0x15, 0xe6 // ldr al r8 r5 minus r7 PostIndex
};
const byte kInstruction_ldr_al_r8_r1_plus_r4_PreIndex[] = {
  0x04, 0x80, 0xb1, 0xe7 // ldr al r8 r1 plus r4 PreIndex
};
const byte kInstruction_ldr_al_r10_r12_plus_r1_PreIndex[] = {
  0x01, 0xa0, 0xbc, 0xe7 // ldr al r10 r12 plus r1 PreIndex
};
const byte kInstruction_ldr_al_r9_r12_plus_r3_PostIndex[] = {
  0x03, 0x90, 0x9c, 0xe6 // ldr al r9 r12 plus r3 PostIndex
};
const byte kInstruction_ldr_al_r10_r3_minus_r13_PostIndex[] = {
  0x0d, 0xa0, 0x13, 0xe6 // ldr al r10 r3 minus r13 PostIndex
};
const byte kInstruction_ldr_al_r5_r10_plus_r5_PostIndex[] = {
  0x05, 0x50, 0x9a, 0xe6 // ldr al r5 r10 plus r5 PostIndex
};
const byte kInstruction_ldr_al_r12_r4_plus_r2_PostIndex[] = {
  0x02, 0xc0, 0x94, 0xe6 // ldr al r12 r4 plus r2 PostIndex
};
const byte kInstruction_ldr_al_r3_r4_plus_r8_PreIndex[] = {
  0x08, 0x30, 0xb4, 0xe7 // ldr al r3 r4 plus r8 PreIndex
};
const byte kInstruction_ldr_al_r6_r9_minus_r12_PostIndex[] = {
  0x0c, 0x60, 0x19, 0xe6 // ldr al r6 r9 minus r12 PostIndex
};
const byte kInstruction_ldr_al_r11_r13_plus_r7_PostIndex[] = {
  0x07, 0xb0, 0x9d, 0xe6 // ldr al r11 r13 plus r7 PostIndex
};
const TestResult kReferenceldr[] = {
  {
    ARRAY_SIZE(kInstruction_ldr_pl_r8_r11_plus_r6_Offset),
    kInstruction_ldr_pl_r8_r11_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r4_r8_plus_r5_Offset),
    kInstruction_ldr_le_r4_r8_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vs_r2_r6_plus_r14_Offset),
    kInstruction_ldr_vs_r2_r6_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r1_r7_plus_r8_Offset),
    kInstruction_ldr_ls_r1_r7_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r14_r6_plus_r14_Offset),
    kInstruction_ldr_ge_r14_r6_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r7_r0_plus_r7_Offset),
    kInstruction_ldr_cs_r7_r0_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r11_r0_plus_r9_Offset),
    kInstruction_ldr_ge_r11_r0_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r7_r10_plus_r4_Offset),
    kInstruction_ldr_eq_r7_r10_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r2_plus_r3_Offset),
    kInstruction_ldr_al_r9_r2_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r11_r10_plus_r6_Offset),
    kInstruction_ldr_cc_r11_r10_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r9_r6_plus_r1_Offset),
    kInstruction_ldr_lt_r9_r6_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r4_r0_plus_r4_Offset),
    kInstruction_ldr_ge_r4_r0_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r13_plus_r14_Offset),
    kInstruction_ldr_al_r9_r13_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r9_r0_plus_r7_Offset),
    kInstruction_ldr_cc_r9_r0_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r11_r7_plus_r8_Offset),
    kInstruction_ldr_cs_r11_r7_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r8_r0_plus_r8_Offset),
    kInstruction_ldr_eq_r8_r0_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_hi_r9_r10_plus_r8_Offset),
    kInstruction_ldr_hi_r9_r10_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r8_r0_plus_r0_Offset),
    kInstruction_ldr_le_r8_r0_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r4_r5_plus_r2_Offset),
    kInstruction_ldr_cs_r4_r5_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r14_r11_plus_r8_Offset),
    kInstruction_ldr_eq_r14_r11_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r7_r6_plus_r14_Offset),
    kInstruction_ldr_cs_r7_r6_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ne_r0_r9_plus_r7_Offset),
    kInstruction_ldr_ne_r0_r9_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r7_r3_plus_r11_Offset),
    kInstruction_ldr_le_r7_r3_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_gt_r7_r9_plus_r9_Offset),
    kInstruction_ldr_gt_r7_r9_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r9_r12_plus_r9_Offset),
    kInstruction_ldr_le_r9_r12_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_pl_r2_r11_plus_r14_Offset),
    kInstruction_ldr_pl_r2_r11_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r1_r7_plus_r2_Offset),
    kInstruction_ldr_cs_r1_r7_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r1_plus_r12_Offset),
    kInstruction_ldr_al_r5_r1_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r10_r13_plus_r12_Offset),
    kInstruction_ldr_eq_r10_r13_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r10_r11_plus_r3_Offset),
    kInstruction_ldr_eq_r10_r11_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r12_plus_r0_Offset),
    kInstruction_ldr_al_r9_r12_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r3_r14_plus_r1_Offset),
    kInstruction_ldr_ls_r3_r14_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r13_r4_plus_r9_Offset),
    kInstruction_ldr_le_r13_r4_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r3_r14_plus_r3_Offset),
    kInstruction_ldr_ls_r3_r14_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r7_r4_plus_r4_Offset),
    kInstruction_ldr_cc_r7_r4_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r5_r9_plus_r5_Offset),
    kInstruction_ldr_ls_r5_r9_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r6_r4_plus_r13_Offset),
    kInstruction_ldr_ge_r6_r4_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r11_plus_r12_Offset),
    kInstruction_ldr_al_r1_r11_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r6_r11_plus_r3_Offset),
    kInstruction_ldr_le_r6_r11_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r6_plus_r13_Offset),
    kInstruction_ldr_al_r6_r6_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_gt_r14_r11_plus_r2_Offset),
    kInstruction_ldr_gt_r14_r11_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vs_r5_r8_plus_r12_Offset),
    kInstruction_ldr_vs_r5_r8_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r8_r12_plus_r6_Offset),
    kInstruction_ldr_ls_r8_r12_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vs_r6_r12_plus_r14_Offset),
    kInstruction_ldr_vs_r6_r12_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_pl_r7_r2_plus_r7_Offset),
    kInstruction_ldr_pl_r7_r2_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_gt_r5_r4_plus_r13_Offset),
    kInstruction_ldr_gt_r5_r4_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_hi_r2_r7_plus_r12_Offset),
    kInstruction_ldr_hi_r2_r7_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ne_r2_r3_plus_r10_Offset),
    kInstruction_ldr_ne_r2_r3_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r13_r2_plus_r6_Offset),
    kInstruction_ldr_lt_r13_r2_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_hi_r14_r10_plus_r11_Offset),
    kInstruction_ldr_hi_r14_r10_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_hi_r7_r10_plus_r12_Offset),
    kInstruction_ldr_hi_r7_r10_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r3_r12_plus_r2_Offset),
    kInstruction_ldr_cs_r3_r12_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r11_r5_plus_r1_Offset),
    kInstruction_ldr_ls_r11_r5_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_hi_r5_r2_plus_r11_Offset),
    kInstruction_ldr_hi_r5_r2_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r11_r8_plus_r6_Offset),
    kInstruction_ldr_cc_r11_r8_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r11_r3_plus_r9_Offset),
    kInstruction_ldr_lt_r11_r3_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ne_r11_r9_plus_r8_Offset),
    kInstruction_ldr_ne_r11_r9_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r7_r0_plus_r14_Offset),
    kInstruction_ldr_lt_r7_r0_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r12_r3_plus_r1_Offset),
    kInstruction_ldr_ge_r12_r3_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r0_r8_plus_r13_Offset),
    kInstruction_ldr_le_r0_r8_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vc_r5_r13_plus_r7_Offset),
    kInstruction_ldr_vc_r5_r13_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r7_r5_plus_r11_Offset),
    kInstruction_ldr_ge_r7_r5_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r10_r9_plus_r3_Offset),
    kInstruction_ldr_ge_r10_r9_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vs_r9_r5_plus_r2_Offset),
    kInstruction_ldr_vs_r9_r5_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_hi_r2_r10_plus_r4_Offset),
    kInstruction_ldr_hi_r2_r10_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ge_r1_r11_plus_r1_Offset),
    kInstruction_ldr_ge_r1_r11_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r9_r14_plus_r12_Offset),
    kInstruction_ldr_ls_r9_r14_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_mi_r1_r9_plus_r4_Offset),
    kInstruction_ldr_mi_r1_r9_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_mi_r7_r10_plus_r4_Offset),
    kInstruction_ldr_mi_r7_r10_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_gt_r6_r2_plus_r5_Offset),
    kInstruction_ldr_gt_r6_r2_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r10_r8_plus_r11_Offset),
    kInstruction_ldr_eq_r10_r8_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_le_r10_r1_plus_r7_Offset),
    kInstruction_ldr_le_r10_r1_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_pl_r8_r14_plus_r8_Offset),
    kInstruction_ldr_pl_r8_r14_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_gt_r5_r1_plus_r3_Offset),
    kInstruction_ldr_gt_r5_r1_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cs_r10_r4_plus_r13_Offset),
    kInstruction_ldr_cs_r10_r4_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_mi_r10_r5_plus_r2_Offset),
    kInstruction_ldr_mi_r10_r5_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r6_r0_plus_r11_Offset),
    kInstruction_ldr_cc_r6_r0_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r3_r9_plus_r2_Offset),
    kInstruction_ldr_eq_r3_r9_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r0_plus_r3_Offset),
    kInstruction_ldr_al_r1_r0_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_mi_r1_r0_plus_r13_Offset),
    kInstruction_ldr_mi_r1_r0_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r4_r4_plus_r5_Offset),
    kInstruction_ldr_cc_r4_r4_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r6_plus_r11_Offset),
    kInstruction_ldr_al_r2_r6_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r1_r5_plus_r4_Offset),
    kInstruction_ldr_ls_r1_r5_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r0_r3_plus_r4_Offset),
    kInstruction_ldr_eq_r0_r3_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r7_r11_plus_r10_Offset),
    kInstruction_ldr_lt_r7_r11_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vc_r3_r0_plus_r13_Offset),
    kInstruction_ldr_vc_r3_r0_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ls_r3_r3_plus_r7_Offset),
    kInstruction_ldr_ls_r3_r3_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r14_plus_r3_Offset),
    kInstruction_ldr_al_r5_r14_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ne_r2_r13_plus_r9_Offset),
    kInstruction_ldr_ne_r2_r13_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r6_r2_plus_r11_Offset),
    kInstruction_ldr_lt_r6_r2_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vc_r9_r2_plus_r13_Offset),
    kInstruction_ldr_vc_r9_r2_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_ne_r5_r9_plus_r6_Offset),
    kInstruction_ldr_ne_r5_r9_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vc_r4_r9_plus_r8_Offset),
    kInstruction_ldr_vc_r4_r9_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_cc_r6_r9_plus_r2_Offset),
    kInstruction_ldr_cc_r6_r9_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_vs_r8_r7_plus_r13_Offset),
    kInstruction_ldr_vs_r8_r7_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_pl_r14_r14_plus_r7_Offset),
    kInstruction_ldr_pl_r14_r14_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_eq_r8_r2_plus_r6_Offset),
    kInstruction_ldr_eq_r8_r2_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r13_plus_r13_Offset),
    kInstruction_ldr_al_r13_r13_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_gt_r12_r14_plus_r5_Offset),
    kInstruction_ldr_gt_r12_r14_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_lt_r14_r7_plus_r1_Offset),
    kInstruction_ldr_lt_r14_r7_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r2_Offset),
    kInstruction_ldr_al_r0_r0_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r8_Offset),
    kInstruction_ldr_al_r0_r0_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r14_Offset),
    kInstruction_ldr_al_r0_r9_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r6_Offset),
    kInstruction_ldr_al_r0_r10_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r8_Offset),
    kInstruction_ldr_al_r0_r5_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r10_Offset),
    kInstruction_ldr_al_r0_r14_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r1_Offset),
    kInstruction_ldr_al_r0_r0_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r7_Offset),
    kInstruction_ldr_al_r0_r2_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r7_Offset),
    kInstruction_ldr_al_r0_r12_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r3_Offset),
    kInstruction_ldr_al_r0_r6_minus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_minus_r11_Offset),
    kInstruction_ldr_al_r0_r4_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r9_Offset),
    kInstruction_ldr_al_r0_r12_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r14_Offset),
    kInstruction_ldr_al_r0_r12_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_minus_r1_Offset),
    kInstruction_ldr_al_r0_r4_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r4_Offset),
    kInstruction_ldr_al_r0_r12_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r5_Offset),
    kInstruction_ldr_al_r0_r13_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r9_Offset),
    kInstruction_ldr_al_r0_r9_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r5_Offset),
    kInstruction_ldr_al_r0_r9_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r11_Offset),
    kInstruction_ldr_al_r0_r2_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r0_Offset),
    kInstruction_ldr_al_r0_r13_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r2_Offset),
    kInstruction_ldr_al_r0_r12_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_plus_r14_Offset),
    kInstruction_ldr_al_r0_r1_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r12_Offset),
    kInstruction_ldr_al_r0_r2_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r11_Offset),
    kInstruction_ldr_al_r0_r8_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r0_Offset),
    kInstruction_ldr_al_r0_r2_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r13_Offset),
    kInstruction_ldr_al_r0_r13_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r4_Offset),
    kInstruction_ldr_al_r0_r13_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r4_Offset),
    kInstruction_ldr_al_r0_r13_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_minus_r14_Offset),
    kInstruction_ldr_al_r0_r4_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r9_Offset),
    kInstruction_ldr_al_r0_r11_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_plus_r10_Offset),
    kInstruction_ldr_al_r0_r3_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_minus_r3_Offset),
    kInstruction_ldr_al_r0_r4_minus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r9_Offset),
    kInstruction_ldr_al_r0_r12_minus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_plus_r1_Offset),
    kInstruction_ldr_al_r0_r3_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r7_Offset),
    kInstruction_ldr_al_r0_r10_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_plus_r9_Offset),
    kInstruction_ldr_al_r0_r6_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r7_Offset),
    kInstruction_ldr_al_r0_r9_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r0_Offset),
    kInstruction_ldr_al_r0_r14_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r3_Offset),
    kInstruction_ldr_al_r0_r4_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r4_Offset),
    kInstruction_ldr_al_r0_r12_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r7_Offset),
    kInstruction_ldr_al_r0_r13_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r0_Offset),
    kInstruction_ldr_al_r0_r7_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r11_Offset),
    kInstruction_ldr_al_r0_r12_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_plus_r4_Offset),
    kInstruction_ldr_al_r0_r0_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_plus_r10_Offset),
    kInstruction_ldr_al_r0_r1_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r6_Offset),
    kInstruction_ldr_al_r0_r5_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r8_Offset),
    kInstruction_ldr_al_r0_r2_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_minus_r4_Offset),
    kInstruction_ldr_al_r0_r4_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r1_Offset),
    kInstruction_ldr_al_r0_r7_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r13_Offset),
    kInstruction_ldr_al_r0_r8_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_plus_r12_Offset),
    kInstruction_ldr_al_r0_r6_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r3_Offset),
    kInstruction_ldr_al_r0_r9_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_plus_r11_Offset),
    kInstruction_ldr_al_r0_r14_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r1_Offset),
    kInstruction_ldr_al_r0_r10_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r11_Offset),
    kInstruction_ldr_al_r0_r13_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r13_Offset),
    kInstruction_ldr_al_r0_r8_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r4_Offset),
    kInstruction_ldr_al_r0_r1_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r10_Offset),
    kInstruction_ldr_al_r0_r13_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r4_Offset),
    kInstruction_ldr_al_r0_r4_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r7_Offset),
    kInstruction_ldr_al_r0_r7_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_minus_r12_Offset),
    kInstruction_ldr_al_r0_r3_minus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r10_Offset),
    kInstruction_ldr_al_r0_r10_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r4_Offset),
    kInstruction_ldr_al_r0_r8_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_plus_r3_Offset),
    kInstruction_ldr_al_r0_r1_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r10_Offset),
    kInstruction_ldr_al_r0_r5_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r0_Offset),
    kInstruction_ldr_al_r0_r1_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r13_Offset),
    kInstruction_ldr_al_r0_r6_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r7_Offset),
    kInstruction_ldr_al_r0_r1_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r8_Offset),
    kInstruction_ldr_al_r0_r12_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r5_Offset),
    kInstruction_ldr_al_r0_r5_minus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_plus_r6_Offset),
    kInstruction_ldr_al_r0_r0_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r0_Offset),
    kInstruction_ldr_al_r0_r11_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r13_Offset),
    kInstruction_ldr_al_r0_r11_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r2_Offset),
    kInstruction_ldr_al_r0_r6_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r6_Offset),
    kInstruction_ldr_al_r0_r2_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r10_Offset),
    kInstruction_ldr_al_r0_r11_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r0_Offset),
    kInstruction_ldr_al_r0_r0_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r13_Offset),
    kInstruction_ldr_al_r0_r9_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r0_Offset),
    kInstruction_ldr_al_r0_r5_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_plus_r2_Offset),
    kInstruction_ldr_al_r0_r5_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r10_Offset),
    kInstruction_ldr_al_r0_r11_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r12_Offset),
    kInstruction_ldr_al_r0_r8_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r6_Offset),
    kInstruction_ldr_al_r0_r8_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r4_Offset),
    kInstruction_ldr_al_r0_r0_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r9_Offset),
    kInstruction_ldr_al_r0_r4_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r11_Offset),
    kInstruction_ldr_al_r0_r12_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r1_Offset),
    kInstruction_ldr_al_r0_r1_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r14_Offset),
    kInstruction_ldr_al_r0_r13_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r0_Offset),
    kInstruction_ldr_al_r0_r13_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r14_Offset),
    kInstruction_ldr_al_r0_r7_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r8_Offset),
    kInstruction_ldr_al_r0_r6_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_plus_r0_Offset),
    kInstruction_ldr_al_r0_r7_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r7_Offset),
    kInstruction_ldr_al_r0_r10_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r0_Offset),
    kInstruction_ldr_al_r0_r6_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r4_Offset),
    kInstruction_ldr_al_r0_r2_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r5_Offset),
    kInstruction_ldr_al_r0_r6_minus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_minus_r7_Offset),
    kInstruction_ldr_al_r0_r3_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r2_Offset),
    kInstruction_ldr_al_r0_r7_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_minus_r8_Offset),
    kInstruction_ldr_al_r0_r4_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r14_Offset),
    kInstruction_ldr_al_r0_r4_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r2_Offset),
    kInstruction_ldr_al_r0_r10_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r6_Offset),
    kInstruction_ldr_al_r0_r14_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r4_Offset),
    kInstruction_ldr_al_r0_r2_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r0_Offset),
    kInstruction_ldr_al_r0_r12_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_plus_r6_Offset),
    kInstruction_ldr_al_r0_r14_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_plus_r0_Offset),
    kInstruction_ldr_al_r0_r1_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r3_Offset),
    kInstruction_ldr_al_r0_r9_minus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_plus_r4_Offset),
    kInstruction_ldr_al_r0_r5_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r7_Offset),
    kInstruction_ldr_al_r0_r2_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r9_Offset),
    kInstruction_ldr_al_r0_r5_minus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r1_Offset),
    kInstruction_ldr_al_r0_r4_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r10_Offset),
    kInstruction_ldr_al_r0_r1_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r4_Offset),
    kInstruction_ldr_al_r0_r5_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r12_Offset),
    kInstruction_ldr_al_r0_r0_minus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r5_Offset),
    kInstruction_ldr_al_r0_r13_minus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r5_Offset),
    kInstruction_ldr_al_r0_r4_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r14_Offset),
    kInstruction_ldr_al_r0_r11_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r14_Offset),
    kInstruction_ldr_al_r0_r1_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r13_Offset),
    kInstruction_ldr_al_r0_r14_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r5_Offset),
    kInstruction_ldr_al_r0_r10_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r4_Offset),
    kInstruction_ldr_al_r0_r6_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r10_Offset),
    kInstruction_ldr_al_r0_r9_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_plus_r5_Offset),
    kInstruction_ldr_al_r0_r7_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r5_Offset),
    kInstruction_ldr_al_r0_r10_minus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r12_Offset),
    kInstruction_ldr_al_r0_r12_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r13_Offset),
    kInstruction_ldr_al_r0_r0_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_minus_r13_Offset),
    kInstruction_ldr_al_r0_r3_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r8_Offset),
    kInstruction_ldr_al_r0_r2_plus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_plus_r2_Offset),
    kInstruction_ldr_al_r0_r0_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r1_Offset),
    kInstruction_ldr_al_r0_r8_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r2_Offset),
    kInstruction_ldr_al_r0_r9_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r14_Offset),
    kInstruction_ldr_al_r0_r10_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_plus_r14_Offset),
    kInstruction_ldr_al_r0_r3_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r3_Offset),
    kInstruction_ldr_al_r0_r12_minus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r9_Offset),
    kInstruction_ldr_al_r0_r8_minus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r5_Offset),
    kInstruction_ldr_al_r0_r14_minus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r14_Offset),
    kInstruction_ldr_al_r0_r10_plus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_plus_r12_Offset),
    kInstruction_ldr_al_r0_r1_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r1_Offset),
    kInstruction_ldr_al_r0_r14_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r12_Offset),
    kInstruction_ldr_al_r0_r8_minus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r2_Offset),
    kInstruction_ldr_al_r0_r11_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r8_Offset),
    kInstruction_ldr_al_r0_r11_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r3_Offset),
    kInstruction_ldr_al_r0_r11_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r9_Offset),
    kInstruction_ldr_al_r0_r7_minus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r7_Offset),
    kInstruction_ldr_al_r0_r11_minus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r1_Offset),
    kInstruction_ldr_al_r0_r12_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_plus_r1_Offset),
    kInstruction_ldr_al_r0_r6_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_plus_r9_Offset),
    kInstruction_ldr_al_r0_r7_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r4_Offset),
    kInstruction_ldr_al_r0_r9_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r5_Offset),
    kInstruction_ldr_al_r0_r12_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r3_Offset),
    kInstruction_ldr_al_r0_r12_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_plus_r5_Offset),
    kInstruction_ldr_al_r0_r3_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r4_Offset),
    kInstruction_ldr_al_r0_r10_minus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r8_Offset),
    kInstruction_ldr_al_r0_r12_minus_r8_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_minus_r5_Offset),
    kInstruction_ldr_al_r0_r12_minus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r6_Offset),
    kInstruction_ldr_al_r0_r13_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r10_Offset),
    kInstruction_ldr_al_r0_r8_plus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_plus_r7_Offset),
    kInstruction_ldr_al_r0_r0_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r2_Offset),
    kInstruction_ldr_al_r0_r11_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_plus_r11_Offset),
    kInstruction_ldr_al_r0_r7_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r3_Offset),
    kInstruction_ldr_al_r0_r13_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r9_Offset),
    kInstruction_ldr_al_r0_r10_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r2_Offset),
    kInstruction_ldr_al_r0_r5_minus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r7_Offset),
    kInstruction_ldr_al_r0_r12_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r14_Offset),
    kInstruction_ldr_al_r0_r5_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_minus_r14_Offset),
    kInstruction_ldr_al_r0_r6_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r3_Offset),
    kInstruction_ldr_al_r0_r2_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r6_Offset),
    kInstruction_ldr_al_r0_r4_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r2_Offset),
    kInstruction_ldr_al_r0_r10_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_plus_r9_Offset),
    kInstruction_ldr_al_r0_r5_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r6_Offset),
    kInstruction_ldr_al_r0_r13_plus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_minus_r0_Offset),
    kInstruction_ldr_al_r0_r8_minus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r14_Offset),
    kInstruction_ldr_al_r0_r9_minus_r14_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_plus_r13_Offset),
    kInstruction_ldr_al_r0_r6_plus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_minus_r11_Offset),
    kInstruction_ldr_al_r0_r3_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_plus_r4_Offset),
    kInstruction_ldr_al_r0_r11_plus_r4_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r3_Offset),
    kInstruction_ldr_al_r0_r2_minus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r13_Offset),
    kInstruction_ldr_al_r0_r7_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_plus_r5_Offset),
    kInstruction_ldr_al_r0_r2_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r10_Offset),
    kInstruction_ldr_al_r0_r0_minus_r10_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r0_Offset),
    kInstruction_ldr_al_r0_r9_plus_r0_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_minus_r6_Offset),
    kInstruction_ldr_al_r0_r0_minus_r6_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_plus_r7_Offset),
    kInstruction_ldr_al_r0_r1_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r11_Offset),
    kInstruction_ldr_al_r0_r13_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r11_Offset),
    kInstruction_ldr_al_r0_r7_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r13_Offset),
    kInstruction_ldr_al_r0_r1_minus_r13_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r1_Offset),
    kInstruction_ldr_al_r0_r9_plus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r12_Offset),
    kInstruction_ldr_al_r0_r10_plus_r12_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r11_Offset),
    kInstruction_ldr_al_r0_r14_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r11_Offset),
    kInstruction_ldr_al_r0_r11_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r9_Offset),
    kInstruction_ldr_al_r0_r8_plus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r5_Offset),
    kInstruction_ldr_al_r0_r8_plus_r5_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r0_plus_r11_Offset),
    kInstruction_ldr_al_r0_r0_plus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_plus_r3_Offset),
    kInstruction_ldr_al_r0_r7_plus_r3_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_minus_r1_Offset),
    kInstruction_ldr_al_r0_r3_minus_r1_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r11_Offset),
    kInstruction_ldr_al_r0_r10_minus_r11_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r2_Offset),
    kInstruction_ldr_al_r0_r4_plus_r2_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r7_Offset),
    kInstruction_ldr_al_r0_r9_plus_r7_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_minus_r9_Offset),
    kInstruction_ldr_al_r0_r9_minus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r9_Offset),
    kInstruction_ldr_al_r0_r1_minus_r9_Offset,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r5_plus_r9_PreIndex),
    kInstruction_ldr_al_r2_r5_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r14_plus_r9_PreIndex),
    kInstruction_ldr_al_r8_r14_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r10_minus_r3_PreIndex),
    kInstruction_ldr_al_r2_r10_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r4_plus_r7_PostIndex),
    kInstruction_ldr_al_r9_r4_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r2_plus_r4_PreIndex),
    kInstruction_ldr_al_r1_r2_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r9_minus_r14_PostIndex),
    kInstruction_ldr_al_r5_r9_minus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r8_plus_r6_PreIndex),
    kInstruction_ldr_al_r1_r8_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r1_minus_r7_PreIndex),
    kInstruction_ldr_al_r13_r1_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r7_minus_r5_PostIndex),
    kInstruction_ldr_al_r14_r7_minus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r11_plus_r14_PostIndex),
    kInstruction_ldr_al_r1_r11_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r14_minus_r6_PreIndex),
    kInstruction_ldr_al_r10_r14_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r13_plus_r11_PostIndex),
    kInstruction_ldr_al_r1_r13_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r12_minus_r7_PostIndex),
    kInstruction_ldr_al_r6_r12_minus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r9_minus_r1_PreIndex),
    kInstruction_ldr_al_r8_r9_minus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r11_plus_r4_PostIndex),
    kInstruction_ldr_al_r2_r11_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r8_minus_r8_PreIndex),
    kInstruction_ldr_al_r7_r8_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r9_plus_r13_PreIndex),
    kInstruction_ldr_al_r5_r9_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r6_minus_r6_PostIndex),
    kInstruction_ldr_al_r1_r6_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r0_plus_r11_PreIndex),
    kInstruction_ldr_al_r11_r0_plus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r4_minus_r10_PreIndex),
    kInstruction_ldr_al_r1_r4_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r3_minus_r1_PreIndex),
    kInstruction_ldr_al_r10_r3_minus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r14_minus_r10_PreIndex),
    kInstruction_ldr_al_r11_r14_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r4_plus_r4_PreIndex),
    kInstruction_ldr_al_r11_r4_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r4_minus_r7_PreIndex),
    kInstruction_ldr_al_r8_r4_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r11_plus_r8_PreIndex),
    kInstruction_ldr_al_r2_r11_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r10_minus_r7_PreIndex),
    kInstruction_ldr_al_r12_r10_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r2_minus_r7_PreIndex),
    kInstruction_ldr_al_r14_r2_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r4_minus_r8_PreIndex),
    kInstruction_ldr_al_r2_r4_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r6_plus_r13_PreIndex),
    kInstruction_ldr_al_r8_r6_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r13_plus_r3_PostIndex),
    kInstruction_ldr_al_r9_r13_plus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r11_plus_r13_PostIndex),
    kInstruction_ldr_al_r7_r11_plus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r9_minus_r9_PostIndex),
    kInstruction_ldr_al_r1_r9_minus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r8_minus_r11_PostIndex),
    kInstruction_ldr_al_r5_r8_minus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r6_PreIndex),
    kInstruction_ldr_al_r0_r10_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r14_minus_r6_PostIndex),
    kInstruction_ldr_al_r11_r14_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r8_minus_r10_PreIndex),
    kInstruction_ldr_al_r5_r8_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r10_minus_r10_PreIndex),
    kInstruction_ldr_al_r9_r10_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r4_plus_r6_PreIndex),
    kInstruction_ldr_al_r1_r4_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r10_minus_r2_PreIndex),
    kInstruction_ldr_al_r11_r10_minus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r2_minus_r6_PostIndex),
    kInstruction_ldr_al_r3_r2_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r1_plus_r13_PreIndex),
    kInstruction_ldr_al_r4_r1_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r7_plus_r3_PostIndex),
    kInstruction_ldr_al_r2_r7_plus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r9_minus_r8_PostIndex),
    kInstruction_ldr_al_r4_r9_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r8_plus_r11_PostIndex),
    kInstruction_ldr_al_r1_r8_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r7_PostIndex),
    kInstruction_ldr_al_r0_r2_minus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r5_plus_r12_PreIndex),
    kInstruction_ldr_al_r6_r5_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_plus_r0_PreIndex),
    kInstruction_ldr_al_r0_r3_plus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r4_plus_r8_PostIndex),
    kInstruction_ldr_al_r5_r4_plus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r0_plus_r6_PostIndex),
    kInstruction_ldr_al_r6_r0_plus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r12_plus_r9_PreIndex),
    kInstruction_ldr_al_r1_r12_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r6_plus_r11_PreIndex),
    kInstruction_ldr_al_r1_r6_plus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r8_minus_r6_PostIndex),
    kInstruction_ldr_al_r6_r8_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r2_plus_r14_PreIndex),
    kInstruction_ldr_al_r3_r2_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r0_minus_r6_PreIndex),
    kInstruction_ldr_al_r9_r0_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r2_minus_r2_PreIndex),
    kInstruction_ldr_al_r7_r2_minus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r0_plus_r12_PreIndex),
    kInstruction_ldr_al_r13_r0_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r14_minus_r3_PreIndex),
    kInstruction_ldr_al_r7_r14_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r3_plus_r13_PreIndex),
    kInstruction_ldr_al_r1_r3_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r8_PostIndex),
    kInstruction_ldr_al_r0_r4_plus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r2_PostIndex),
    kInstruction_ldr_al_r0_r11_minus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r6_minus_r12_PreIndex),
    kInstruction_ldr_al_r9_r6_minus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r12_minus_r9_PreIndex),
    kInstruction_ldr_al_r8_r12_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r10_minus_r11_PreIndex),
    kInstruction_ldr_al_r12_r10_minus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r7_plus_r1_PostIndex),
    kInstruction_ldr_al_r10_r7_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r14_minus_r6_PreIndex),
    kInstruction_ldr_al_r8_r14_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r8_minus_r2_PostIndex),
    kInstruction_ldr_al_r6_r8_minus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r9_plus_r5_PostIndex),
    kInstruction_ldr_al_r10_r9_plus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r12_minus_r4_PreIndex),
    kInstruction_ldr_al_r5_r12_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r4_plus_r4_PreIndex),
    kInstruction_ldr_al_r5_r4_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r9_minus_r3_PreIndex),
    kInstruction_ldr_al_r8_r9_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r11_minus_r5_PreIndex),
    kInstruction_ldr_al_r7_r11_minus_r5_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r6_minus_r6_PostIndex),
    kInstruction_ldr_al_r9_r6_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r5_plus_r3_PreIndex),
    kInstruction_ldr_al_r11_r5_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r0_minus_r4_PreIndex),
    kInstruction_ldr_al_r9_r0_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r1_PostIndex),
    kInstruction_ldr_al_r0_r12_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r0_minus_r6_PreIndex),
    kInstruction_ldr_al_r1_r0_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r0_minus_r5_PreIndex),
    kInstruction_ldr_al_r10_r0_minus_r5_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r4_plus_r3_PreIndex),
    kInstruction_ldr_al_r8_r4_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r12_minus_r5_PreIndex),
    kInstruction_ldr_al_r14_r12_minus_r5_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r13_minus_r9_PreIndex),
    kInstruction_ldr_al_r4_r13_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r13_minus_r4_PreIndex),
    kInstruction_ldr_al_r8_r13_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r6_minus_r8_PostIndex),
    kInstruction_ldr_al_r11_r6_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r5_plus_r9_PostIndex),
    kInstruction_ldr_al_r9_r5_plus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r4_minus_r6_PreIndex),
    kInstruction_ldr_al_r9_r4_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r9_minus_r13_PreIndex),
    kInstruction_ldr_al_r4_r9_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r10_plus_r10_PreIndex),
    kInstruction_ldr_al_r2_r10_plus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r8_plus_r4_PreIndex),
    kInstruction_ldr_al_r11_r8_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r1_minus_r0_PreIndex),
    kInstruction_ldr_al_r7_r1_minus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r10_plus_r12_PreIndex),
    kInstruction_ldr_al_r5_r10_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_minus_r9_PostIndex),
    kInstruction_ldr_al_r0_r5_minus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r7_minus_r7_PostIndex),
    kInstruction_ldr_al_r14_r7_minus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r0_minus_r12_PostIndex),
    kInstruction_ldr_al_r12_r0_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r13_PreIndex),
    kInstruction_ldr_al_r0_r13_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r7_minus_r4_PostIndex),
    kInstruction_ldr_al_r9_r7_minus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r10_minus_r0_PostIndex),
    kInstruction_ldr_al_r7_r10_minus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r0_plus_r11_PostIndex),
    kInstruction_ldr_al_r7_r0_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r8_plus_r9_PreIndex),
    kInstruction_ldr_al_r2_r8_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r14_plus_r2_PreIndex),
    kInstruction_ldr_al_r12_r14_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r6_minus_r8_PostIndex),
    kInstruction_ldr_al_r3_r6_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r11_plus_r8_PreIndex),
    kInstruction_ldr_al_r10_r11_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r8_PostIndex),
    kInstruction_ldr_al_r0_r7_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r9_plus_r1_PostIndex),
    kInstruction_ldr_al_r14_r9_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r9_plus_r9_PostIndex),
    kInstruction_ldr_al_r0_r9_plus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r2_plus_r14_PostIndex),
    kInstruction_ldr_al_r3_r2_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r5_plus_r12_PostIndex),
    kInstruction_ldr_al_r3_r5_plus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r5_plus_r4_PreIndex),
    kInstruction_ldr_al_r9_r5_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r11_minus_r5_PostIndex),
    kInstruction_ldr_al_r7_r11_minus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r13_PreIndex),
    kInstruction_ldr_al_r0_r4_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r4_plus_r10_PreIndex),
    kInstruction_ldr_al_r2_r4_plus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r9_plus_r2_PostIndex),
    kInstruction_ldr_al_r14_r9_plus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r9_plus_r1_PostIndex),
    kInstruction_ldr_al_r10_r9_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r6_PreIndex),
    kInstruction_ldr_al_r0_r13_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r0_minus_r10_PostIndex),
    kInstruction_ldr_al_r2_r0_minus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_minus_r3_PreIndex),
    kInstruction_ldr_al_r0_r10_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r7_minus_r9_PreIndex),
    kInstruction_ldr_al_r1_r7_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r6_minus_r11_PostIndex),
    kInstruction_ldr_al_r13_r6_minus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r6_plus_r12_PreIndex),
    kInstruction_ldr_al_r4_r6_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r7_minus_r2_PostIndex),
    kInstruction_ldr_al_r12_r7_minus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r9_minus_r6_PreIndex),
    kInstruction_ldr_al_r11_r9_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r11_minus_r8_PostIndex),
    kInstruction_ldr_al_r13_r11_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r3_minus_r13_PreIndex),
    kInstruction_ldr_al_r13_r3_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r9_plus_r1_PostIndex),
    kInstruction_ldr_al_r2_r9_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r2_minus_r12_PostIndex),
    kInstruction_ldr_al_r9_r2_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r0_minus_r9_PreIndex),
    kInstruction_ldr_al_r10_r0_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r11_minus_r3_PreIndex),
    kInstruction_ldr_al_r4_r11_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r7_plus_r12_PreIndex),
    kInstruction_ldr_al_r2_r7_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r2_plus_r0_PreIndex),
    kInstruction_ldr_al_r14_r2_plus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r4_minus_r2_PreIndex),
    kInstruction_ldr_al_r13_r4_minus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r6_plus_r13_PreIndex),
    kInstruction_ldr_al_r13_r6_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r1_minus_r4_PostIndex),
    kInstruction_ldr_al_r2_r1_minus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r2_minus_r8_PreIndex),
    kInstruction_ldr_al_r4_r2_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r6_PostIndex),
    kInstruction_ldr_al_r0_r8_plus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r10_minus_r13_PreIndex),
    kInstruction_ldr_al_r11_r10_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r0_plus_r3_PreIndex),
    kInstruction_ldr_al_r10_r0_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r6_minus_r10_PreIndex),
    kInstruction_ldr_al_r1_r6_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r2_plus_r13_PostIndex),
    kInstruction_ldr_al_r12_r2_plus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r2_minus_r0_PostIndex),
    kInstruction_ldr_al_r14_r2_minus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r9_minus_r10_PreIndex),
    kInstruction_ldr_al_r4_r9_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r1_plus_r14_PostIndex),
    kInstruction_ldr_al_r8_r1_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r2_minus_r13_PostIndex),
    kInstruction_ldr_al_r14_r2_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r5_plus_r6_PostIndex),
    kInstruction_ldr_al_r4_r5_plus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r2_minus_r0_PostIndex),
    kInstruction_ldr_al_r13_r2_minus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r0_plus_r14_PostIndex),
    kInstruction_ldr_al_r12_r0_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r2_plus_r8_PostIndex),
    kInstruction_ldr_al_r3_r2_plus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r2_minus_r0_PreIndex),
    kInstruction_ldr_al_r12_r2_minus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r7_minus_r13_PostIndex),
    kInstruction_ldr_al_r14_r7_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r12_minus_r7_PreIndex),
    kInstruction_ldr_al_r2_r12_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r10_plus_r12_PreIndex),
    kInstruction_ldr_al_r12_r10_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r1_plus_r4_PostIndex),
    kInstruction_ldr_al_r11_r1_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r12_PostIndex),
    kInstruction_ldr_al_r0_r8_plus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r13_minus_r3_PreIndex),
    kInstruction_ldr_al_r8_r13_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r4_minus_r6_PostIndex),
    kInstruction_ldr_al_r8_r4_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r6_PreIndex),
    kInstruction_ldr_al_r0_r7_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r6_plus_r2_PreIndex),
    kInstruction_ldr_al_r5_r6_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r1_minus_r4_PreIndex),
    kInstruction_ldr_al_r8_r1_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r6_minus_r11_PreIndex),
    kInstruction_ldr_al_r8_r6_minus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r5_plus_r12_PreIndex),
    kInstruction_ldr_al_r10_r5_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r9_plus_r6_PreIndex),
    kInstruction_ldr_al_r5_r9_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r5_plus_r7_PostIndex),
    kInstruction_ldr_al_r0_r5_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r13_plus_r5_PostIndex),
    kInstruction_ldr_al_r3_r13_plus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r14_minus_r1_PostIndex),
    kInstruction_ldr_al_r3_r14_minus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r11_PostIndex),
    kInstruction_ldr_al_r0_r13_minus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r7_plus_r14_PreIndex),
    kInstruction_ldr_al_r3_r7_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r8_minus_r7_PostIndex),
    kInstruction_ldr_al_r1_r8_minus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r3_minus_r1_PostIndex),
    kInstruction_ldr_al_r6_r3_minus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r8_plus_r7_PostIndex),
    kInstruction_ldr_al_r5_r8_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r1_plus_r6_PostIndex),
    kInstruction_ldr_al_r3_r1_plus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r0_minus_r9_PostIndex),
    kInstruction_ldr_al_r4_r0_minus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r7_minus_r6_PostIndex),
    kInstruction_ldr_al_r14_r7_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r5_minus_r4_PreIndex),
    kInstruction_ldr_al_r3_r5_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r14_plus_r14_PreIndex),
    kInstruction_ldr_al_r11_r14_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r14_plus_r5_PreIndex),
    kInstruction_ldr_al_r3_r14_plus_r5_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r11_minus_r11_PreIndex),
    kInstruction_ldr_al_r1_r11_minus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r7_plus_r14_PostIndex),
    kInstruction_ldr_al_r11_r7_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r9_plus_r13_PostIndex),
    kInstruction_ldr_al_r7_r9_plus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r11_plus_r14_PostIndex),
    kInstruction_ldr_al_r3_r11_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r6_minus_r6_PreIndex),
    kInstruction_ldr_al_r3_r6_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r3_minus_r6_PreIndex),
    kInstruction_ldr_al_r2_r3_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r11_plus_r1_PostIndex),
    kInstruction_ldr_al_r2_r11_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r12_plus_r10_PostIndex),
    kInstruction_ldr_al_r13_r12_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r2_plus_r11_PreIndex),
    kInstruction_ldr_al_r1_r2_plus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r12_plus_r14_PreIndex),
    kInstruction_ldr_al_r3_r12_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r6_plus_r11_PostIndex),
    kInstruction_ldr_al_r0_r6_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r6_minus_r13_PostIndex),
    kInstruction_ldr_al_r4_r6_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r8_minus_r13_PreIndex),
    kInstruction_ldr_al_r11_r8_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r3_minus_r6_PostIndex),
    kInstruction_ldr_al_r5_r3_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r1_plus_r2_PostIndex),
    kInstruction_ldr_al_r8_r1_plus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r5_minus_r13_PreIndex),
    kInstruction_ldr_al_r11_r5_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r9_plus_r2_PostIndex),
    kInstruction_ldr_al_r7_r9_plus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r10_plus_r11_PostIndex),
    kInstruction_ldr_al_r3_r10_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r12_plus_r11_PreIndex),
    kInstruction_ldr_al_r0_r12_plus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r4_plus_r14_PostIndex),
    kInstruction_ldr_al_r7_r4_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r5_plus_r1_PreIndex),
    kInstruction_ldr_al_r11_r5_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r2_plus_r3_PostIndex),
    kInstruction_ldr_al_r3_r2_plus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r8_minus_r4_PostIndex),
    kInstruction_ldr_al_r11_r8_minus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r5_plus_r10_PostIndex),
    kInstruction_ldr_al_r14_r5_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r3_minus_r3_PreIndex),
    kInstruction_ldr_al_r13_r3_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r3_minus_r8_PostIndex),
    kInstruction_ldr_al_r2_r3_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r13_minus_r1_PreIndex),
    kInstruction_ldr_al_r2_r13_minus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_plus_r1_PostIndex),
    kInstruction_ldr_al_r0_r13_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r5_plus_r3_PreIndex),
    kInstruction_ldr_al_r6_r5_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r3_plus_r12_PreIndex),
    kInstruction_ldr_al_r0_r3_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r7_plus_r3_PreIndex),
    kInstruction_ldr_al_r4_r7_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r14_plus_r11_PostIndex),
    kInstruction_ldr_al_r11_r14_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r14_PreIndex),
    kInstruction_ldr_al_r0_r11_minus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r9_plus_r2_PostIndex),
    kInstruction_ldr_al_r11_r9_plus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r1_minus_r12_PreIndex),
    kInstruction_ldr_al_r14_r1_minus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r6_plus_r1_PreIndex),
    kInstruction_ldr_al_r5_r6_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r5_minus_r3_PostIndex),
    kInstruction_ldr_al_r10_r5_minus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r4_plus_r8_PreIndex),
    kInstruction_ldr_al_r1_r4_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r14_plus_r0_PostIndex),
    kInstruction_ldr_al_r12_r14_plus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r0_plus_r10_PreIndex),
    kInstruction_ldr_al_r1_r0_plus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r11_plus_r14_PreIndex),
    kInstruction_ldr_al_r13_r11_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r8_plus_r13_PostIndex),
    kInstruction_ldr_al_r7_r8_plus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r3_minus_r11_PostIndex),
    kInstruction_ldr_al_r2_r3_minus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r11_plus_r8_PreIndex),
    kInstruction_ldr_al_r8_r11_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r13_plus_r12_PreIndex),
    kInstruction_ldr_al_r7_r13_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r10_plus_r7_PostIndex),
    kInstruction_ldr_al_r2_r10_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r4_minus_r6_PreIndex),
    kInstruction_ldr_al_r5_r4_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r2_plus_r4_PostIndex),
    kInstruction_ldr_al_r10_r2_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r9_minus_r14_PreIndex),
    kInstruction_ldr_al_r4_r9_minus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r11_plus_r8_PostIndex),
    kInstruction_ldr_al_r3_r11_plus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r13_minus_r8_PreIndex),
    kInstruction_ldr_al_r14_r13_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r13_minus_r7_PreIndex),
    kInstruction_ldr_al_r5_r13_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r2_minus_r2_PreIndex),
    kInstruction_ldr_al_r5_r2_minus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r2_minus_r9_PreIndex),
    kInstruction_ldr_al_r9_r2_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r7_plus_r11_PreIndex),
    kInstruction_ldr_al_r2_r7_plus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r6_minus_r14_PreIndex),
    kInstruction_ldr_al_r2_r6_minus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r6_minus_r6_PreIndex),
    kInstruction_ldr_al_r7_r6_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r1_minus_r13_PreIndex),
    kInstruction_ldr_al_r10_r1_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r3_minus_r13_PostIndex),
    kInstruction_ldr_al_r7_r3_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r1_minus_r8_PreIndex),
    kInstruction_ldr_al_r3_r1_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r1_plus_r12_PostIndex),
    kInstruction_ldr_al_r13_r1_plus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r14_plus_r3_PostIndex),
    kInstruction_ldr_al_r13_r14_plus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r5_plus_r7_PostIndex),
    kInstruction_ldr_al_r9_r5_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r2_plus_r8_PreIndex),
    kInstruction_ldr_al_r3_r2_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r8_minus_r9_PostIndex),
    kInstruction_ldr_al_r1_r8_minus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r14_minus_r8_PostIndex),
    kInstruction_ldr_al_r11_r14_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r12_minus_r6_PostIndex),
    kInstruction_ldr_al_r2_r12_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r1_minus_r12_PostIndex),
    kInstruction_ldr_al_r4_r1_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r6_minus_r13_PreIndex),
    kInstruction_ldr_al_r13_r6_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r9_minus_r13_PostIndex),
    kInstruction_ldr_al_r5_r9_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r8_minus_r12_PostIndex),
    kInstruction_ldr_al_r4_r8_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r9_plus_r12_PreIndex),
    kInstruction_ldr_al_r5_r9_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r13_minus_r3_PreIndex),
    kInstruction_ldr_al_r11_r13_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r13_minus_r13_PreIndex),
    kInstruction_ldr_al_r4_r13_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r7_plus_r0_PostIndex),
    kInstruction_ldr_al_r3_r7_plus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r11_minus_r8_PostIndex),
    kInstruction_ldr_al_r5_r11_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r0_minus_r0_PreIndex),
    kInstruction_ldr_al_r5_r0_minus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r1_minus_r1_PostIndex),
    kInstruction_ldr_al_r0_r1_minus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r12_minus_r0_PreIndex),
    kInstruction_ldr_al_r5_r12_minus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r1_plus_r7_PreIndex),
    kInstruction_ldr_al_r6_r1_plus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r13_minus_r8_PreIndex),
    kInstruction_ldr_al_r5_r13_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r8_plus_r11_PostIndex),
    kInstruction_ldr_al_r3_r8_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r0_plus_r2_PreIndex),
    kInstruction_ldr_al_r8_r0_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r14_plus_r6_PreIndex),
    kInstruction_ldr_al_r10_r14_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r2_minus_r0_PostIndex),
    kInstruction_ldr_al_r12_r2_minus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r0_minus_r1_PreIndex),
    kInstruction_ldr_al_r13_r0_minus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r6_minus_r10_PreIndex),
    kInstruction_ldr_al_r12_r6_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r7_minus_r0_PostIndex),
    kInstruction_ldr_al_r0_r7_minus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r7_minus_r3_PreIndex),
    kInstruction_ldr_al_r1_r7_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r2_plus_r13_PostIndex),
    kInstruction_ldr_al_r9_r2_plus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r11_minus_r3_PostIndex),
    kInstruction_ldr_al_r0_r11_minus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r1_plus_r1_PreIndex),
    kInstruction_ldr_al_r2_r1_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r4_plus_r5_PostIndex),
    kInstruction_ldr_al_r5_r4_plus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r13_plus_r4_PostIndex),
    kInstruction_ldr_al_r7_r13_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_plus_r6_PreIndex),
    kInstruction_ldr_al_r0_r14_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r1_plus_r7_PostIndex),
    kInstruction_ldr_al_r10_r1_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r5_plus_r12_PostIndex),
    kInstruction_ldr_al_r12_r5_plus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r2_PreIndex),
    kInstruction_ldr_al_r0_r10_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r13_plus_r8_PreIndex),
    kInstruction_ldr_al_r7_r13_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r10_plus_r9_PreIndex),
    kInstruction_ldr_al_r14_r10_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r2_plus_r1_PreIndex),
    kInstruction_ldr_al_r1_r2_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r7_plus_r12_PreIndex),
    kInstruction_ldr_al_r6_r7_plus_r12_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r1_plus_r3_PreIndex),
    kInstruction_ldr_al_r10_r1_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r4_plus_r11_PostIndex),
    kInstruction_ldr_al_r6_r4_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r0_plus_r12_PostIndex),
    kInstruction_ldr_al_r14_r0_plus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r7_minus_r12_PostIndex),
    kInstruction_ldr_al_r4_r7_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r10_plus_r10_PostIndex),
    kInstruction_ldr_al_r13_r10_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r4_minus_r1_PreIndex),
    kInstruction_ldr_al_r9_r4_minus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r7_minus_r2_PreIndex),
    kInstruction_ldr_al_r2_r7_minus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r6_plus_r2_PreIndex),
    kInstruction_ldr_al_r10_r6_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r14_minus_r2_PostIndex),
    kInstruction_ldr_al_r8_r14_minus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r9_minus_r14_PostIndex),
    kInstruction_ldr_al_r4_r9_minus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r8_plus_r12_PostIndex),
    kInstruction_ldr_al_r3_r8_plus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r12_plus_r8_PostIndex),
    kInstruction_ldr_al_r3_r12_plus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r6_minus_r10_PreIndex),
    kInstruction_ldr_al_r4_r6_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r14_plus_r6_PreIndex),
    kInstruction_ldr_al_r3_r14_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r1_plus_r7_PreIndex),
    kInstruction_ldr_al_r2_r1_plus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r9_plus_r2_PreIndex),
    kInstruction_ldr_al_r7_r9_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r6_plus_r10_PostIndex),
    kInstruction_ldr_al_r11_r6_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r2_plus_r11_PostIndex),
    kInstruction_ldr_al_r5_r2_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r10_plus_r10_PreIndex),
    kInstruction_ldr_al_r8_r10_plus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r0_minus_r10_PreIndex),
    kInstruction_ldr_al_r8_r0_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r4_plus_r2_PreIndex),
    kInstruction_ldr_al_r0_r4_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r4_minus_r8_PreIndex),
    kInstruction_ldr_al_r3_r4_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r0_minus_r11_PreIndex),
    kInstruction_ldr_al_r1_r0_minus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r2_minus_r9_PreIndex),
    kInstruction_ldr_al_r0_r2_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r12_plus_r13_PostIndex),
    kInstruction_ldr_al_r14_r12_plus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r10_minus_r5_PreIndex),
    kInstruction_ldr_al_r13_r10_minus_r5_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r0_plus_r11_PostIndex),
    kInstruction_ldr_al_r9_r0_plus_r11_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r11_plus_r7_PostIndex),
    kInstruction_ldr_al_r2_r11_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r5_plus_r10_PreIndex),
    kInstruction_ldr_al_r7_r5_plus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r3_minus_r2_PostIndex),
    kInstruction_ldr_al_r4_r3_minus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r6_minus_r6_PostIndex),
    kInstruction_ldr_al_r2_r6_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r1_minus_r9_PreIndex),
    kInstruction_ldr_al_r11_r1_minus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r13_plus_r5_PostIndex),
    kInstruction_ldr_al_r5_r13_plus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r13_minus_r13_PostIndex),
    kInstruction_ldr_al_r1_r13_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r10_plus_r10_PostIndex),
    kInstruction_ldr_al_r0_r10_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r10_plus_r9_PreIndex),
    kInstruction_ldr_al_r5_r10_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r13_minus_r2_PostIndex),
    kInstruction_ldr_al_r0_r13_minus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r8_minus_r0_PostIndex),
    kInstruction_ldr_al_r7_r8_minus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r9_minus_r12_PostIndex),
    kInstruction_ldr_al_r2_r9_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r3_minus_r5_PostIndex),
    kInstruction_ldr_al_r9_r3_minus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r5_minus_r12_PostIndex),
    kInstruction_ldr_al_r6_r5_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r4_minus_r10_PreIndex),
    kInstruction_ldr_al_r11_r4_minus_r10_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r14_plus_r1_PostIndex),
    kInstruction_ldr_al_r10_r14_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r5_plus_r0_PreIndex),
    kInstruction_ldr_al_r8_r5_plus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r13_plus_r13_PreIndex),
    kInstruction_ldr_al_r10_r13_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r8_plus_r13_PreIndex),
    kInstruction_ldr_al_r0_r8_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r13_plus_r8_PreIndex),
    kInstruction_ldr_al_r10_r13_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r6_minus_r4_PreIndex),
    kInstruction_ldr_al_r11_r6_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r9_plus_r10_PostIndex),
    kInstruction_ldr_al_r1_r9_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r12_minus_r12_PostIndex),
    kInstruction_ldr_al_r3_r12_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r6_minus_r6_PreIndex),
    kInstruction_ldr_al_r13_r6_minus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r14_plus_r4_PostIndex),
    kInstruction_ldr_al_r9_r14_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r10_minus_r13_PostIndex),
    kInstruction_ldr_al_r12_r10_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r11_minus_r7_PreIndex),
    kInstruction_ldr_al_r7_r11_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r4_minus_r12_PostIndex),
    kInstruction_ldr_al_r11_r4_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r14_plus_r8_PreIndex),
    kInstruction_ldr_al_r8_r14_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r1_plus_r14_PreIndex),
    kInstruction_ldr_al_r12_r1_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r4_plus_r2_PostIndex),
    kInstruction_ldr_al_r3_r4_plus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r8_minus_r5_PostIndex),
    kInstruction_ldr_al_r6_r8_minus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r14_plus_r4_PostIndex),
    kInstruction_ldr_al_r12_r14_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r10_minus_r8_PostIndex),
    kInstruction_ldr_al_r3_r10_minus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r7_plus_r1_PreIndex),
    kInstruction_ldr_al_r12_r7_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r9_minus_r7_PreIndex),
    kInstruction_ldr_al_r14_r9_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r12_plus_r1_PreIndex),
    kInstruction_ldr_al_r7_r12_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r11_minus_r4_PreIndex),
    kInstruction_ldr_al_r10_r11_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r9_minus_r3_PreIndex),
    kInstruction_ldr_al_r4_r9_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r13_plus_r14_PreIndex),
    kInstruction_ldr_al_r2_r13_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r12_minus_r13_PreIndex),
    kInstruction_ldr_al_r1_r12_minus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r10_plus_r6_PostIndex),
    kInstruction_ldr_al_r6_r10_plus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_minus_r7_PreIndex),
    kInstruction_ldr_al_r0_r14_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r13_minus_r13_PostIndex),
    kInstruction_ldr_al_r5_r13_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r11_minus_r6_PostIndex),
    kInstruction_ldr_al_r2_r11_minus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r9_plus_r14_PostIndex),
    kInstruction_ldr_al_r5_r9_plus_r14_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r2_plus_r7_PostIndex),
    kInstruction_ldr_al_r7_r2_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r2_plus_r2_PreIndex),
    kInstruction_ldr_al_r9_r2_plus_r2_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r0_r14_plus_r14_PreIndex),
    kInstruction_ldr_al_r0_r14_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r13_minus_r0_PreIndex),
    kInstruction_ldr_al_r14_r13_minus_r0_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r3_minus_r5_PreIndex),
    kInstruction_ldr_al_r7_r3_minus_r5_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r0_minus_r10_PostIndex),
    kInstruction_ldr_al_r14_r0_minus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r1_r2_minus_r4_PreIndex),
    kInstruction_ldr_al_r1_r2_minus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r3_minus_r5_PostIndex),
    kInstruction_ldr_al_r8_r3_minus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r5_plus_r6_PreIndex),
    kInstruction_ldr_al_r3_r5_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r12_plus_r9_PostIndex),
    kInstruction_ldr_al_r4_r12_plus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r12_minus_r3_PreIndex),
    kInstruction_ldr_al_r4_r12_minus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r0_minus_r5_PostIndex),
    kInstruction_ldr_al_r12_r0_minus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r4_plus_r7_PostIndex),
    kInstruction_ldr_al_r12_r4_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r5_minus_r7_PreIndex),
    kInstruction_ldr_al_r6_r5_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r11_plus_r4_PostIndex),
    kInstruction_ldr_al_r10_r11_plus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r12_plus_r7_PreIndex),
    kInstruction_ldr_al_r3_r12_plus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r10_plus_r4_PreIndex),
    kInstruction_ldr_al_r3_r10_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r8_plus_r6_PreIndex),
    kInstruction_ldr_al_r6_r8_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r5_plus_r8_PostIndex),
    kInstruction_ldr_al_r4_r5_plus_r8_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r13_r0_minus_r3_PostIndex),
    kInstruction_ldr_al_r13_r0_minus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r2_minus_r14_PreIndex),
    kInstruction_ldr_al_r7_r2_minus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r10_plus_r3_PostIndex),
    kInstruction_ldr_al_r3_r10_plus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r4_minus_r1_PostIndex),
    kInstruction_ldr_al_r10_r4_minus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r5_minus_r1_PreIndex),
    kInstruction_ldr_al_r6_r5_minus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r3_plus_r5_PostIndex),
    kInstruction_ldr_al_r7_r3_plus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r8_plus_r13_PreIndex),
    kInstruction_ldr_al_r7_r8_plus_r13_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r13_plus_r4_PreIndex),
    kInstruction_ldr_al_r10_r13_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r3_plus_r1_PostIndex),
    kInstruction_ldr_al_r8_r3_plus_r1_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r6_plus_r3_PreIndex),
    kInstruction_ldr_al_r14_r6_plus_r3_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r5_minus_r4_PostIndex),
    kInstruction_ldr_al_r3_r5_minus_r4_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r7_plus_r6_PreIndex),
    kInstruction_ldr_al_r5_r7_plus_r6_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r4_r12_minus_r9_PostIndex),
    kInstruction_ldr_al_r4_r12_minus_r9_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r3_plus_r14_PreIndex),
    kInstruction_ldr_al_r7_r3_plus_r14_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r14_r8_minus_r7_PreIndex),
    kInstruction_ldr_al_r14_r8_minus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r7_minus_r11_PreIndex),
    kInstruction_ldr_al_r2_r7_minus_r11_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r6_plus_r7_PreIndex),
    kInstruction_ldr_al_r8_r6_plus_r7_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r3_plus_r7_PostIndex),
    kInstruction_ldr_al_r9_r3_plus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r7_r0_minus_r8_PreIndex),
    kInstruction_ldr_al_r7_r0_minus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r1_plus_r9_PreIndex),
    kInstruction_ldr_al_r6_r1_plus_r9_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r2_r13_plus_r6_PostIndex),
    kInstruction_ldr_al_r2_r13_plus_r6_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r7_plus_r10_PostIndex),
    kInstruction_ldr_al_r11_r7_plus_r10_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r8_plus_r0_PostIndex),
    kInstruction_ldr_al_r9_r8_plus_r0_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r4_minus_r12_PostIndex),
    kInstruction_ldr_al_r3_r4_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r5_minus_r7_PostIndex),
    kInstruction_ldr_al_r8_r5_minus_r7_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r8_r1_plus_r4_PreIndex),
    kInstruction_ldr_al_r8_r1_plus_r4_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r12_plus_r1_PreIndex),
    kInstruction_ldr_al_r10_r12_plus_r1_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r9_r12_plus_r3_PostIndex),
    kInstruction_ldr_al_r9_r12_plus_r3_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r10_r3_minus_r13_PostIndex),
    kInstruction_ldr_al_r10_r3_minus_r13_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r5_r10_plus_r5_PostIndex),
    kInstruction_ldr_al_r5_r10_plus_r5_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r12_r4_plus_r2_PostIndex),
    kInstruction_ldr_al_r12_r4_plus_r2_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r3_r4_plus_r8_PreIndex),
    kInstruction_ldr_al_r3_r4_plus_r8_PreIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r6_r9_minus_r12_PostIndex),
    kInstruction_ldr_al_r6_r9_minus_r12_PostIndex,
  },
  {
    ARRAY_SIZE(kInstruction_ldr_al_r11_r13_plus_r7_PostIndex),
    kInstruction_ldr_al_r11_r13_plus_r7_PostIndex,
  },
};

#endif  // VIXL_ASSEMBLER_COND_RD_MEMOP_RS_LDR_A32_H_
